@@ -31,7 +31,7 @@ munipack gphot 0716_*.fits
 
 # astrometry calibration
 munipack cone -c UCAC5 -r 0.2 -- 110.5 71.3
-munipack astrometry --maxmatch 20 -c cone.fits 0716_*.fits
+munipack astrometry -c 'cone.fits[1][$f.mag$>11.and.$f.mag$<15]' 0716_*.fits
 
 # photometry calibration
 wget http://munipack.physics.muni.cz/0716+71.lst
@@ -40,12 +40,27 @@ munipack fits --restore 0716+71.lst
 munipack cone -c UCAC4 -o cone_ucac4.fits -r 0.2 -- 110.5 71.3
 python ucac_jmuc.py cone_ucac4.fits cone_Johnson.fits
 
+#SAPER="--saper 5"
+#THRESH="-th 0.1 -e 0.01"
+for FILTER in V R; do
+  #munipack kombine --average -o 0716.${FILTER}.fits 0716_04?${FILTER}.fits
+  cp 0716_042${FILTER}.fits 0716.${FILTER}.fits
+  munipack find 0716.${FILTER}.fits
+  munipack aphot 0716.${FILTER}.fits
+  munipack astrometry -c 'cone.fits[1][$f.mag$>11.and.$f.mag$<15]' \
+	   0716.${FILTER}.fits
+  munipack phcal --verbose --photsys-ref Johnson -f ${FILTER} --area 0.3 \
+	   -c 0716+71.fits --col-mag ${FILTER}mag --col-magerr e_${FILTER}mag \
+	   $THRESH $SAPER 0716.${FILTER}.fits
+done
+
+
 for FILTER in V R; do
 
   # manual
   for A in 0716_*${FILTER}.fits; do
     munipack phcal -C 1 --photsys-ref Johnson -f ${FILTER} \
-        --saper 4 -O --mask '\!\1_mancal.\2' $A;
+        $SAPER -O --mask '\!\1_mancal.\2' $A;
   done
 
   # mancal, aperture 7, extinction
@@ -81,18 +96,16 @@ for FILTER in V R; do
         --photsys-ref Johnson --area 0.3 \
         -f ${FILTER} --col-mag ${FILTER}mag --col-magerr e_${FILTER}mag  \
         -c 0716+71.fits \
-        --saper 4 \
-	-O --mask '\!\1_catcal.\2' \
-        $A;
+        $THRESH $SAPER  \
+	-O --mask '\!\1_catcal.\2' $A;
   done
 
   # reference frame
   for A in 0716_*${FILTER}.fits; do
       munipack phcal \
-        --photsys-ref Johnson --area 0.3 \
-        -f ${FILTER}  \
-	--saper 4 \
-        -r 0716_035${FILTER}_catcal.fits -O --mask '\!\1_refcal.\2' $A;
+        --photsys-ref Johnson -f ${FILTER} --area 0.3 \
+	$THRESH $SAPER -r 0716.${FILTER}_cal.fits \
+        -O --mask '\!\1_refcal.\2' $A;
   done
 
   # ucac
@@ -100,16 +113,34 @@ for FILTER in V R; do
       munipack phcal \
         --photsys-ref Johnson --area 0.3 --col-ra RAJ2000 --col-dec DEJ2000 \
         -f ${FILTER} --col-mag ${FILTER}mag --col-magerr e_${FILTER}mag  \
-        -c cone_Johnson.fits \
-	--saper 4 \
-        -O --mask '\!\1_ucacal.\2' \
-        $A;
+	-c "cone_Johnson.fits[1][e_${FILTER}mag<0.1]" $THRESH $SAPER \
+        -O --mask '\!\1_ucacal.\2' $A;
   done
 
 done
 
-#munipack kombine --rcen 110.47 --dcen 71.34 --width 640 --height 480 -o V.fits 0716_*V.fits
-#munipack kombine --rcen 110.47 --dcen 71.34 --width 640 --height 480 -o R.fits 0716_*R.fits
+munipack kombine --average  --rcen 110.47 --dcen 71.34 --width 640 --height 480 -o V.fits 0716_*V_catcal.fits
+munipack kombine --average --rcen 110.47 --dcen 71.34 --width 640 --height 480 -o R.fits 0716_*R_catcal.fits
+
+#for FILTER in V R; do
+#    munipack find ${FILTER}.fits
+#    munipack aphot ${FILTER}.fits
+#    munipack astrometry -c 'cone.fits[1][$f.mag$>11.and.$f.mag$<15]' \
+#	     ${FILTER}.fits
+#    munipack phcal \
+#        --photsys-ref Johnson --area 0.3 --col-ra RAJ2000 --col-dec DEJ2000 \
+#        -f ${FILTER} --col-mag ${FILTER}mag --col-magerr e_${FILTER}mag  \
+#	-c "cone_Johnson.fits[1][e_${FILTER}mag<0.1]" $THRESH $SAPER \
+#        -O --mask '\!\1_cal.\2' ${FILTER}.fits;
+#
+#    # reference frame
+#  for A in 0716_*${FILTER}.fits; do
+#      munipack phcal \
+#        --photsys-ref Johnson -f ${FILTER} --area 0.3 \
+#	$THRESH $SAPER -r ${FILTER}_cal.fits \
+#        -O --mask '\!\1_refcal.\2' $A;
+#  done
+#done
 
 
 # light curves
@@ -164,7 +195,10 @@ set xlabel "JD - 2453409"
 set yrange[14.8:13.5]
 set term svg dynamic
 set output 'lc0716_V.svg'
-plot 'mancal_V' u (\$1-2453409):(\$2-\$4+11.8) t "diff(0716+71 - A) + 11.8", 'catcal_V' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, 'refcal_V' u (\$1-2453409):2 t "frame" ls 1 lc 3, 'ucacal_V' u (\$1-2453409):(\$2+0.1) t "UCAC4 + 0.2" ls 1 lc 4
+plot 'mancal_V' u (\$1-2453409):(\$2-\$4+11.8) t "diff(0716+71 - A) + 11.8", \
+     'catcal_V' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, \
+     'refcal_V' u (\$1-2453409):2 t "frame" ls 1 lc 3, \
+     'ucacal_V' u (\$1-2453409):(\$2+0.2) t "UCAC4 + 0.2" ls 1 lc 4
 EOF
 
 
@@ -173,10 +207,14 @@ set key top left
 set title "Calibration star A"
 set ylabel "magnitude in V"
 set xlabel "JD - 2453409"
-set yrange[11.9:11.2]
+set yrange[12:11]
+set ytics 0.1
 set term svg dynamic
 set output 'comp0716_V.svg'
-plot 'mancal_V' u (\$1-2453409):(\$4-\$6+12.65) t "diff(A-B)+12.65", 'catcal_V' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, 'refcal_V' u (\$1-2453409):4 t "frame" ls 1 lc 3, 'ucacal_V' u (\$1-2453409):(\$4+0.1) t "UCAC4 + 0.2" ls 1 lc 4
+plot 'mancal_V' u (\$1-2453409):(\$4-\$6+12.65) t "diff(A-B)+12.65", \
+     'catcal_V' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, \
+     'refcal_V' u (\$1-2453409):4 t "frame" ls 1 lc 3, \
+     'ucacal_V' u (\$1-2453409):(\$4+0.2) t "UCAC4 + 0.2" ls 1 lc 4
 EOF
 
 # plots, R filter
@@ -188,7 +226,10 @@ set xlabel "JD - 2453409"
 set yrange[14.5:13.0]
 set term svg dynamic
 set output 'lc0716_R.svg'
-plot 'mancal_R' u (\$1-2453409):(\$2-\$4+11.7) t "diff(0716+71 - A) + 11.7", 'catcal_R' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, 'refcal_R' u (\$1-2453409):2 t "frame" ls 1 lc 3, 'ucacal_R' u (\$1-2453409):(\$2+0.1) t "UCAC4 + 0.2" ls 1 lc 4
+plot 'mancal_R' u (\$1-2453409):(\$2-\$4+11.7) t "diff(0716+71 - A) + 11.7", \
+     'catcal_R' u (\$1-2453409):(\$2-0.2) t "std.field - 0.2" ls 1 lc 2, \
+     'refcal_R' u (\$1-2453409):2 t "frame" ls 1 lc 3, \
+     'ucacal_R' u (\$1-2453409):(\$2+0.1) t "UCAC4 + 0.1" ls 1 lc 4
 EOF
 
 
@@ -197,10 +238,14 @@ set key top left
 set title "Calibration star A"
 set ylabel "magnitude in R"
 set xlabel "JD - 2453409"
-set yrange[11.8:10.8]
+set yrange[11.7:10.7]
+set ytics 0.1
 set term svg dynamic
 set output 'comp0716_R.svg'
-plot 'mancal_R' u (\$1-2453409):(\$4-\$6+12.5) t "diff(A-B+12.5)", 'catcal_R' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, 'refcal_R' u (\$1-2453409):4 t "frame" ls 1 lc 3, 'ucacal_R' u (\$1-2453409):(\$4+0.1) t "UCAC4 + 0.2" ls 1 lc 4
+plot 'mancal_R' u (\$1-2453409):(\$4-\$6+12.5) t "diff(A-B+12.5)", \
+     'catcal_R' u (\$1-2453409):(\$4-0.1) t "std.field - 0.1" ls 1 lc 2, \
+     'refcal_R' u (\$1-2453409):4 t "frame" ls 1 lc 3, \
+     'ucacal_R' u (\$1-2453409):(\$4+0.1) t "UCAC4 + 0.1" ls 1 lc 4
 EOF
 
 
@@ -214,7 +259,10 @@ set xrange[1:1.8]
 set yrange[17:16.3]
 set term svg dynamic
 set output 'ext.svg'
-plot 'ext_R' u 2:6 t "R total flux", 'ext7_R' u 2:6 t "R flux in 7-th aperture" ls 1 lc 2, 'ext_V' u 2:6 t "V total flux", 'ext7_V' u 2:6 t "V flux in 7-th aperture" ls 1 lc 2
+plot 'ext_R' u 2:6 t "R total flux", \
+     'ext7_R' u 2:6 t "R flux in 7-th aperture" ls 1 lc 2, \
+     'ext_V' u 2:6 t "V total flux", \
+     'ext7_V' u 2:6 t "V flux in 7-th aperture" ls 1 lc 2
 EOF
 
 
@@ -227,7 +275,8 @@ set xlabel "JD - 2453409"
 set yrange[0:15]
 set term svg dynamic
 set output 'rf90.svg'
-plot 'rf90_R' u (\$1-2453409):2 t "R filter", 'rf90_V' u (\$1-2453409):2 t "V filter" ls 1 lc 2
+plot 'rf90_R' u (\$1-2453409):2 t "R filter", \
+     'rf90_V' u (\$1-2453409):2 t "V filter" ls 1 lc 2
 EOF
 
 # aperture affair
@@ -239,5 +288,8 @@ set xlabel "JD - 2453409"
 set yrange[-0.4:-1.4]
 set term svg dynamic
 set output 'apertures.svg'
-plot 'mancal_V' u (\$1-2453409):(\$4-\$6) t "total flux", 'mancal7_V' u (\$1-2453409):(\$4-\$6 + 0.1) t "aperture 7-th" ls 1 lc 2, 'mancal4_V' u (\$1-2453409):(\$4-\$6 - 0.1) t "aperture 4-th" ls 1 lc 3, 'mancal10_V' u (\$1-2453409):(\$4-\$6 + 0.2) t "aperture 10-th" ls 1 lc 4
+plot 'mancal_V' u (\$1-2453409):(\$4-\$6) t "total flux", \
+     'mancal7_V' u (\$1-2453409):(\$4-\$6 + 0.1) t "aperture 7-th" ls 1 lc 2, \
+     'mancal4_V' u (\$1-2453409):(\$4-\$6 - 0.1) t "aperture 4-th" ls 1 lc 3, \
+     'mancal10_V' u (\$1-2453409):(\$4-\$6 + 0.2) t "aperture 10-th" ls 1 lc 4
 EOF
