@@ -35,8 +35,9 @@ records = [
     record("0.5.5",link,"Nights Without Convergence",2014,04,01),
     record("0.5.6",link,"Photon Calibration",2015,01,05),
     record("0.5.7",link,"Growth Curve",2016,10,25),
-    record("0.5.8",link,"Artificial Sky",2017,07,14)
-    record("0.5.9",link,"Artificial Sky",2017,07,18)
+    record("0.5.8",link,"Artificial Sky",2017,07,14),
+    record("0.5.9",link,"Artificial Sky",2017,07,18),
+    record("0.5.10",link,"Flat-fielding",2018,01,16)
 ]
 
 for r in records:
