@@ -49,11 +49,11 @@
   AddOption("B","bitpix","bitpix (-32,32,16,8)",wxCMD_LINE_VAL_NUMBER);
 
 #define COMMON_OPTIONS_PHTOLLS \
-  AddOption("","tol-temp",L"limit for nearby temperatures (1°C)",wxCMD_LINE_VAL_DOUBLE); \
+  AddOption("","tol-temp",L"limit for nearby temperatures (1°C)",wxCMD_LINE_VAL_DOUBLE);\
   AddOption("","tol-exp",L"limit for nearby exposure times (1μsec)",wxCMD_LINE_VAL_DOUBLE);
 
 #define COMMON_OPTIONS_ARITH \
-  AddSwitch("a",wxEmptyString,"arithmetical instead of robust mean");
+  AddSwitch(wxEmptyString,"arith","arithmetical mean instead of robust mean");
 
 #define COMMON_OPTIONS_ADDKEY \
   AddOption("K","keys","key=value[,key=,..] add keyword(s) to header",wxCMD_LINE_VAL_STRING,wxCMD_LINE_PARAM_MULTIPLE);
@@ -91,13 +91,13 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
 		 " calibrate\tcalibrate\n"
 		 */
 		 "\nActions:\n"
-		 " phcorr\t\tApply photometric precorrections\n"
+		 " phcorr\t\tApply photometric corrections\n"
 		 " bias\t\tAveraged bias frame\n"
 		 " dark\t\tAveraged dark frame\n"
 		 " flat\t\tAveraged flat-field frame\n"
-		 " coloring\tCompose color frame\n"
+		 " coloring\tCompose colour frame\n"
 		 " kombine\tCompose frames (deep exposures, mosaics)\n"
-		 " ctrafo\t\tTransform color frames between color-spaces\n"
+		 " ctrafo\t\tTransform colour frames between colour-spaces\n"
 		 " cone\t\tCone search in a catalogue on Virtual Observatory\n"
 		 " astrometry\tAstrometry calibration\n"
 		 " find\t\tSearch for stars on frames\n"
@@ -105,7 +105,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
 		 " gphot\t\tGrowth-Curve photometry\n"
 		 " phcal\t\tPhotometry calibration\n"
 		 " artificial\tArtificial frames\n"
-		 " phfotran\tDetermine photometry system color transformation\n"
+		 " phfotran\tDetermine photometry system transformation\n"
 		 " timeseries\tList arbitrary quantity to time-series\n"
 		 "\nLow Level Actions:\n"
 		 " votable\tConversions of VOTables\n"
@@ -140,8 +140,8 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddUsageText("Usage: munipack "+action+" [options] file(s)");
     AddUsageText("* Averaged dark frame.");
 
-    COMMON_OPTIONS_ARITH
     AddOption("bias",wxEmptyString,"bias frame");
+    COMMON_OPTIONS_ARITH
     COMMON_OPTIONS_PHTOLLS
     COMMON_OPTIONS_BITPIX
     COMMON_OPTIONS_SINGLE
@@ -153,13 +153,17 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddUsageText("Usage: munipack "+action+" [options] file(s)");
     AddUsageText("* Averaged flat-field frame.");
 
+    AddOption("gain","","provide value of gain (rather than FITS keyword)",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("bias",wxEmptyString,"bias frame");
     AddOption("dark",wxEmptyString,"dark frame");
-    AddOption("xdark",wxEmptyString,"dark frame multiplicator factor",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("gain","","provide value of gain (rather than FITS keyword)",wxCMD_LINE_VAL_DOUBLE);
-    AddSwitch("","gain-estimate","estimate gain");
-    AddOption(wxEmptyString,"level","output mean level (default 1.0)",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"saturate","saturation in ADU",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("xdark",wxEmptyString,"dark frame exposure time factor",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("bitmask",wxEmptyString,"mask frame");
+    AddOption("st","saturate","saturation in counts",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("th","threshold","threshold in counts",wxCMD_LINE_VAL_DOUBLE);
+    AddSwitch("","gain-estimate","rough estimate of gain");
+    AddOption("","approximation","precision: basic, standard (default)");
     COMMON_OPTIONS_BITPIX
     COMMON_OPTIONS_SINGLE
     AddParam("file(s)",wxCMD_LINE_VAL_STRING,wxCMD_LINE_PARAM_MULTIPLE);
@@ -168,17 +172,19 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
   else if( action == "phcorr" ) {
 
     AddUsageText("Usage: munipack "+action+" [options] file(s)[,result(s)]");
-    AddUsageText("* Apply photometric precorrections (gain, bias, dark, flat-field).");
+    AddUsageText("* Apply photometric corrections (gain, bias, dark, flat-field).");
 
+    AddOption("gain","","provide value of gain (rather than FITS keyword)",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("flat",wxEmptyString,"flat-field frame");
     AddOption("bias",wxEmptyString,"bias frame");
     AddOption("dark",wxEmptyString,"dark frame");
-    AddOption("xdark",wxEmptyString,"dark frame multiplicator factor",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("xdark",wxEmptyString,"dark frame exposure time factor",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("bitmask",wxEmptyString,"mask frame");
     AddOption("xbitmask",wxEmptyString,"mask frame as ZERO (default), MEAN (average)");
-    AddOption("gain","","provide value of gain (rather than FITS keyword)",wxCMD_LINE_VAL_DOUBLE);
     AddSwitch("","gain-ignore","ignore gain transformation");
-    AddSwitch(wxEmptyString,"normalise","Normalise on averaged flat-field level");
+    AddSwitch(wxEmptyString,"normalise","normalise flat-field prior to use");
     AddSwitch(wxEmptyString,"force","apply to already corrected frames");
     COMMON_OPTIONS_PHTOLLS
     COMMON_OPTIONS_BITPIX
@@ -189,10 +195,10 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
   else if( action == "coloring" ) {
 
     AddUsageText("Usage: munipack "+action+" [options] file(s)[,ext(s)]");
-    AddUsageText("* Compose color frame.");
+    AddUsageText("* Compose colour frame.");
 
     AddOption("c",wxEmptyString,"colorspace");
-    AddOption("ct",wxEmptyString,"color table");
+    AddOption("ct",wxEmptyString,"colour table");
     COMMON_OPTIONS_BITPIX
     COMMON_OPTIONS_SINGLE
     AddParam("files[,exts]",wxCMD_LINE_VAL_STRING,
@@ -202,11 +208,11 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
   else if( action == "ctrafo" ) {
 
     AddUsageText("Usage: munipack "+action+" [options] file black(s),weight(s)");
-    AddUsageText("* Transform color frames between various color-spaces.");
+    AddUsageText("* Transform colour frames between various colour-spaces.");
 
-    AddSwitch(wxEmptyString,"list","known colospaces");
-    AddOption("c",wxEmptyString,"colorspace");
-    AddOption("ct",wxEmptyString,"color table");
+    AddSwitch(wxEmptyString,"list","known collapses");
+    AddOption("c",wxEmptyString,"collapse");
+    AddOption("ct",wxEmptyString,"colour table");
     COMMON_OPTIONS_BITPIX
     COMMON_OPTIONS_SINGLE
     AddParam("file black,weight",wxCMD_LINE_VAL_STRING,
@@ -219,7 +225,8 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddUsageText("* Cone search in catalogues of Virtual Observatory.");
 
     AddOption("c","cat","catalogue (see --list-catalogues)");
-    AddOption("r","radius","radius for cone search [deg] (default 0.1)",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("r","radius","radius for cone search [deg] (default: 6 arcmin = 0.1)",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("s","sort","sort by the column");
     AddOption("","par","add optional parameters");
     AddOption("","url","service URL");
@@ -242,9 +249,11 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddOption("","type","type of output file: fits,csv,txt,svg,xml");
     AddOption("s","","sort by the column");
     AddOption("pt","","select projection: gnomon");
-    AddOption("pa","","Right Ascension of projection center",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("pd","","Declination of projection center",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("pa","","Right Ascension of projection centre",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("pd","","Declination of projection centre",wxCMD_LINE_VAL_DOUBLE);
     AddOption("ps","","scale of projection",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("pw","","canvas width",wxCMD_LINE_VAL_NUMBER);
+    AddOption("ph","","canvas height",wxCMD_LINE_VAL_NUMBER);
     AddOption("ml","","magnitude limit",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","col-ra","Right Ascension column");
     AddOption("","col-dec","Declination column");
@@ -265,28 +274,46 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddOption("p","projection","projection type: none, gnomonic (default)");
     AddOption(wxEmptyString,"col-ra","Right Ascension column");
     AddOption(wxEmptyString,"col-dec","Declination column");
-    AddOption(wxEmptyString,"col-pm-ra","Proper motion in Right Ascension column");
+    AddOption(wxEmptyString,"col-pm-ra",
+	      "Proper motion in Right Ascension column");
     AddOption(wxEmptyString,"col-pm-dec","Proper motion in Declination column");
     AddOption(wxEmptyString,"col-mag","Magnitude-like column");
-    AddOption(wxEmptyString,"xcen","center of frame [pix] (default: width/2)",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"ycen","center of frame [pix] (default: height/2)",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"rcen","center of FOV in Right Ascension [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"dcen","center of FOV in Declination [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"xcen","centre of frame [pix] (default: width/2)",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"ycen","centre of frame [pix] (default: height/2)",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"rcen","centre of FOV in Right Ascension [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"dcen","center of FOV in Declination [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption(wxEmptyString,"scale","scale [deg/pix]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"angle","rotation angle [deg], clockwise positive",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"angle","rotation angle [deg], clockwise positive",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddSwitch(wxEmptyString,"reflex","set reflection");
     AddOption(wxEmptyString,"fit","robust (default) or squares");
-    AddOption(wxEmptyString,"units","output units: deg,arcmin,arcsec,mas,uas,pix");
-    AddOption(wxEmptyString,"rms","random errors in positions [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"sig","errors of centroids on frame [pix]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"sigcat","coordinate errors of cat/ref [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"fsig","error in fluxes, default=1",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"minmatch","minimal length of match sequence",wxCMD_LINE_VAL_NUMBER);
-    AddOption(wxEmptyString,"maxmatch","maximum length of match sequence",wxCMD_LINE_VAL_NUMBER);
+    AddOption(wxEmptyString,"units",
+	      "output units: deg,arcmin,arcsec,mas,uas,pix");
+    AddOption(wxEmptyString,"rms","random errors in positions [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"sig","errors of centroids on frame [pix]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"sigcat","coordinate errors of cat/ref [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"fsig","error in fluxes, default=1",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"minmatch","minimal length of match sequence",
+	      wxCMD_LINE_VAL_NUMBER);
+    AddOption(wxEmptyString,"maxmatch","maximum length of match sequence",
+	      wxCMD_LINE_VAL_NUMBER);
+    AddOption(wxEmptyString,"luckymatch","minimal reliable sequence, default=3",
+	      wxCMD_LINE_VAL_NUMBER);
     AddOption("","seq1","sequence for reference");
     AddOption("","seq2","sequence for calibrated");
-    AddSwitch(wxEmptyString,"disable-full-match","disable full match");
-    AddSwitch(wxEmptyString,"disable-flux-check","fluxes are not used during matching");
+    AddSwitch(wxEmptyString,"disable-lucky-match",
+	      "finish at first success match");
+    AddSwitch(wxEmptyString,"enable-full-match","enable full match");
+    AddSwitch(wxEmptyString,"disable-flux-check",
+	      "fluxes are not used during matching");
     AddSwitch(wxEmptyString,"disable-rms-check","disable RMS check");
     AddSwitch(wxEmptyString,"disable-save","don't save calibration to header");
     AddSwitch(wxEmptyString,"remove","remove complete astrometry calibration");
@@ -351,7 +378,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
 
     AddOption("c","column","column name(s) to list");
     AddOption("C","coocolumn","column name(s) of coordinates (object search)");
-    AddOption("x","extname","FITS extension identificator");
+    AddOption("x","extname","FITS extension identification");
     AddOption("T","time-type","JD (default), MJD, HJD, PHASE");
     AddOption(wxEmptyString,"time-stamp","MID (default), BEGIN, END");
     AddOption(wxEmptyString,"time-err","uncertainty in the time measurement [s]",wxCMD_LINE_VAL_DOUBLE);
@@ -450,17 +477,27 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddUsageText("* Compose frames (deep exposures, mosaics).");
 
     AddOption("p","projection","projection: identity, gnomonic");
-    AddOption(wxEmptyString,"xcen","center of frame [pix] (default: width/2)",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"ycen","center of frame [pix] (default: height/2)",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"rcen","center of FOV in Right Ascension [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"dcen","center of FOV in Declination [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"width","width of output [pix]",wxCMD_LINE_VAL_NUMBER);
-    AddOption(wxEmptyString,"height","height of output [pix]",wxCMD_LINE_VAL_NUMBER);
-    AddOption(wxEmptyString,"scale","scale [pix/deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"angle","position angle [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"xcen","centre of frame [pix] (default: width/2)",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"ycen","centre of frame [pix] (default: height/2)",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"rcen","centre of FOV in Right Ascension [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"dcen","centre of FOV in Declination [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"width","width of output [pix]",
+	      wxCMD_LINE_VAL_NUMBER);
+    AddOption(wxEmptyString,"height","height of output [pix]",
+	      wxCMD_LINE_VAL_NUMBER);
+    AddOption(wxEmptyString,"scale","scale [pix/deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"angle","position angle [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","reflex","[yes|no] set/unset reflection");
     AddOption("i","interpol","interpolation: none,bilinear,bicubic"); //,bspline
     AddSwitch("","adjust","adjust sky level");
     AddSwitch("","expomask","use exposure mask");
+    AddSwitch("","average","compute average instead of summation");
     COMMON_OPTIONS_BITPIX
     COMMON_OPTIONS_SINGLE
     AddParam("file(s)",wxCMD_LINE_VAL_STRING,wxCMD_LINE_PARAM_MULTIPLE);
@@ -475,6 +512,9 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
     AddOption("c","cat","reference photometry catalogue");
     AddOption("r","ref","reference frame");
     AddOption("f","filters","list of filters");
+    AddOption("th","threshold","select stars with the threshold above sky",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("e","maxerr","select stars with the maximal relative error",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","apcorr","aperture correction",wxCMD_LINE_VAL_DOUBLE);
     AddOption(wxEmptyString,"col-ra","Right Ascension column");
     AddOption(wxEmptyString,"col-dec","Declination column");
     AddOption(wxEmptyString,"col-mag","magnitude column(s)");
@@ -497,7 +537,7 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
   else if( action == "phfotran" ) {
 
     AddUsageText("Usage: munipack "+action+" [options] file(s)");
-    AddUsageText("* Determine photometry system color transformation.");
+    AddUsageText("* Determine photometry system colour transformation.");
 
     AddOption("c","cat","reference photometry catalogue");
     AddOption("f","filters","list of filters");
@@ -525,44 +565,59 @@ MuniCmdLineParser::MuniCmdLineParser(const wxString& action, int xargc, wchar_t
 
     AddOption("","psf","PSF function: SEEING, MOFFAT, GAUSS");
     AddOption("","spread","seeing spread method: FFT, RANDOM, AUTO");
-    AddOption("","hwhm","half width at half of maximum [pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","hwhm","half width at half of maximum [pix]",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","airy","radius of Airy spot [pix]",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","beta","Moffat exponent",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","maglim","magnitude limit",wxCMD_LINE_VAL_NUMBER);
     AddOption("","lc-model","light curve model: Cepheid,Algol,wave(default)");
     AddOption("","lc-table","light curve model in the table");
     AddOption("","lc-fourier","light curve model by Fourier coefficients");
-    AddOption("","lc-mag","mean magnitude of the variable object",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-mag","mean magnitude of the variable object",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","lc-amp","amplitude of the curve",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","lc-jd0","reference Julian date for the light curve",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","lc-per","period for the light curve [days]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","lc-ra","variable object Right Ascension [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","lc-dec","variable object Declination [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","back-level","background level [cts]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","back-noise","background noise [cts]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","back-grad-x","background gradient in x [cts/pix]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","back-grad-y","background gradient in y [cts/pix]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-jd0","reference Julian date for the light curve",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-per","period for the light curve [days]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-ra","variable object Right Ascension [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lc-dec","variable object Declination [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","sky-mag","sky brightness [mag/arcsec2]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","sky-grad-x","sky change in x direction [mag/arcsec2/pix]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","sky-grad-y","sky change in y direction [mag/arcsec2/pix]",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","area","area of input aperture [m2]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","diameter","diameter of input aperture [m]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","diameter","diameter of input aperture [m]",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","exptime","exposure time [s]",wxCMD_LINE_VAL_DOUBLE);
     AddOption("","qeff","quantum efficiency",wxCMD_LINE_VAL_DOUBLE);
-    AddSwitch("","atmosphere","apply atmosphere modelling: extinction, seeing");
+    AddSwitch("","atmosphere","apply atmosphere modelling: extinction+seeing");
     AddOption("","extk","extinction coefficient",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","long","geographic longitude of station (-east)[deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption("","lat","geographic latitude of station (+north)[deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","long","geographic longitude of station (-east)[deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption("","lat","geographic latitude of station (+north)[deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","date","initial date as YYYY-MM-DD");
     AddOption("","time","initial time as HH:MM:SS");
-    AddOption("","count","total number of generated files",wxCMD_LINE_VAL_NUMBER);
+    AddOption("","count","total number of generated files",
+	      wxCMD_LINE_VAL_NUMBER);
     AddOption("","timestep","timestep in seconds",wxCMD_LINE_VAL_DOUBLE);
     AddOption("f","filter","photometry filter");
 
     AddOption("c","cat","reference photometry catalogue");
 
     AddOption("","fov","field of view [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"rcen","center of FOV in Right Ascension [deg]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"dcen","center of FOV in Declination [deg]",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"rcen","centre of FOV in Right Ascension [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"dcen","centre of FOV in Declination [deg]",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption(wxEmptyString,"scale","scale [deg/pix]",wxCMD_LINE_VAL_DOUBLE);
-    AddOption(wxEmptyString,"angle","rotation angle [deg], clockwise positive",wxCMD_LINE_VAL_DOUBLE);
+    AddOption(wxEmptyString,"angle","rotation angle [deg], clockwise positive",
+	      wxCMD_LINE_VAL_DOUBLE);
     AddOption("","width","width of output [pix]",wxCMD_LINE_VAL_NUMBER);
     AddOption("","height","height of output [pix]",wxCMD_LINE_VAL_NUMBER);
     AddOption("","col-ra","Right Ascension column");
