@@ -28,7 +28,7 @@
 bool Munipack::grow_report(MuniProcess *action, MuniCmdLineParser& cmd)
 {
   for(size_t i = 0; i < cmd.GetParamCount(); i++)
-    action->Write(cmd.GetParam(i));
+    action->Write("FILE = '"+cmd.GetParam(i)+"'");
 
   return true;
 }
