@@ -348,7 +348,8 @@ VOResource::VOResource(const wxXmlNode *root)
 
 VOTable::VOTable(const wxURL& url): wxXmlDocument(),index(0),timeout(60)
 {
-  canvas_size = 200.0;
+  canvas_width = 500;
+  canvas_height = 500;
   mag_limit = 15.0;
   proj_scale = 1000.0;
 
@@ -384,7 +385,8 @@ VOTable::VOTable(const wxURL& url): wxXmlDocument(),index(0),timeout(60)
 
 VOTable::VOTable(const wxXmlDocument& vt): wxXmlDocument(vt),index(0),timeout(120)
 {
-  canvas_size = 200.0;
+  canvas_width = 500;
+  canvas_height = 500;
   mag_limit = 15.0;
   proj_scale = 1000.0;
 
@@ -436,7 +438,11 @@ void VOTable::SetProjectionCenter(double a,double d)
   proj_alpha = a;
   proj_delta = d;
 }
-void VOTable::SetSize(double l) { canvas_size = l; }
+void VOTable::SetCanvasSize(long w, long h)
+{
+  canvas_width = w;
+  canvas_height = h;
+}
 void VOTable::SetScale(double c) { proj_scale = c; }
 void VOTable::SetMaglim(double x) { mag_limit = x; }
 void VOTable::SetMagkey(const wxString& a) { mag_key = a; }
@@ -785,8 +791,13 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
   //  vector<wxString> tf = TypeTrafo(ft);
   vector<wxString> tf = FitsTypes();
   vector<wxString> tu = fu;
+
+  // Vizier catalogues reports magnitude errors (e_Vmag) in an obscure
+  // format as type character (or short in past) like '02' for 0.02 (!?).
+  // These values are converted to more convenient form.
   for(size_t i = 0; i < tf.size(); i++) {
     if( fu[i] == "cmag" ) {
+      ft[i] = "float";
       tu[i] == "mag";
       tf[i] = "1E";
     }
@@ -815,31 +826,12 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
   double epoch = GetEpoch();
   fits_write_key(file,TDOUBLE,"EPOCH",&epoch,"reference time (epoch)",&status);
 
-  for(size_t i = 0; i < fs.size(); i++) {
+  for(size_t i = 0; i < fs.size() && status == 0 ; i++) {
 
     vector<wxString> c = GetColumn(i);
     size_t n = c.size();
 
-    if( ft[i] == "short" && fu[i] == "cmag" ) { // fucking cmags!
-
-      float *x = new float[n];
-      for(size_t j = 0; j < n; j++) {
-	long t;
-	if( c[j].ToLong(&t) )
-	  x[j] = t/100.0;
-	else {
-	  x[j] = nan("");
-	  if( c[j] != "" ) {
-	    wxLogError("Failed convert element `"+c[j]+"' at row=%d col="+fs[i]+
-		       " to float.",(int)j);
-	  }
-	}
-      }
-      fits_write_col(file,TFLOAT,i+1,1,1,n,x,&status);
-      delete[] x;
-
-    }
-    else if( ft[i] == "boolean" ) {
+    if( ft[i] == "boolean" ) {
       char *x = new char[n];
       for(size_t j = 0; j < n; j++) {
 	if( c[j]== "T" || c[j]== "t" || c[j]== "1" )
@@ -957,11 +949,12 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
     }
 
     else if( ft[i] == "float" ) {
+      float scale = fu[i] == "cmag" ? 0.01 : 1.0;
       float *x = new float[n];
       for(size_t j = 0; j < n; j++) {
 	double t;
 	if( c[j].ToDouble(&t) )
-	  x[j] = t;
+	  x[j] = scale*t;
 	else {
 	  x[j] = nan("");
 	  if( c[j] != "" ) {
@@ -975,11 +968,12 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
     }
 
     else if( ft[i] == "double" ) {
+      double scale = fu[i] == "cmag" ? 0.01 : 1.0;
       double *x = new double[n];
       for(size_t j = 0; j < n; j++) {
 	double t;
 	if( c[j].ToDouble(&t) )
-	  x[j] = t;
+	  x[j] = scale*t;
 	else {
 	  x[j] = nan("");
 	  if( c[j] != "" ) {
@@ -1015,6 +1009,7 @@ bool VOTable::SaveFITS(const wxString& fitsname, const wxString& backup)
     }
 
   }
+
   if( fits_close_file(file, &status) )
     fits_report_error(stderr,status);
 
@@ -1054,7 +1049,9 @@ bool VOTable::SaveSVG(wxOutputStream& output)
   vector<wxString> xmag = GetColumn(nmag);
 
   wxTextOutputStream cout(output);
-  cout << "<svg xmlns=\"http://www.w3.org/2000/svg\">" << endl;
+  cout << "<svg xmlns=\"http://www.w3.org/2000/svg\""
+       << " width=\"" << int(canvas_width)
+       << "\" height=\"" << int(canvas_height) << "\">" << endl;
 
   // WARNING: only simple gnonomical projection is implemented
 
@@ -1063,12 +1060,13 @@ bool VOTable::SaveSVG(wxOutputStream& output)
     double ra = ToDouble(xra[i]);
     double dec = ToDouble(xdec[i]);
     double mag = ToDouble(xmag[i]);
-    double x = canvas_size - proj_scale*(ra - proj_alpha)*c;
-    double y = canvas_size - proj_scale*(dec - proj_delta);// reverse y-axis !!
+    double x = canvas_width/2 - proj_scale*(ra - proj_alpha)*c;
+    double y = canvas_height/2 - proj_scale*(dec - proj_delta);//reverse y-axis!
     double r = 3.0*pow(10.0,0.11*(mag_limit - mag));
 
-    cout << "<circle cx=\"" << x << "\" cy=\"" << y
-	 << "\" r=\"" << r << "\"/>" << endl;
+    if( 0 <= x && x <= canvas_width && 0 <= y && y <= canvas_height )
+      cout << "<circle cx=\"" << x << "\" cy=\"" << y
+	   << "\" r=\"" << r << "\"/>" << endl;
   }
 
   cout << "</svg>" << endl;
@@ -1170,6 +1168,18 @@ double GetDouble(const wxString& line)
   return 666; // formally
 }
 
+long GetLong(const wxString& line)
+{
+  long l;
+  wxString a = line.AfterFirst('=');
+
+  if( a.ToCLong(&l) )
+    return l;
+
+  wxLogFatalError("Failed to read the number: "+a);
+  return 0; // formally
+}
+
 bool GetBool(const wxString& line)
 {
   wxRegEx re(".+ = (.*)");
