@@ -2,7 +2,7 @@
 
   xmunipack - astrometry
 
-  Copyright © 2011-5 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2011-5,2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -10,12 +10,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -30,7 +30,7 @@
 #include <wx/sstream.h>
 #include <wx/wfstream.h>
 #include <wx/txtstrm.h>
-#include <wx/filefn.h> 
+#include <wx/filefn.h>
 #include <wx/richtooltip.h>
 #include <list>
 #include <cfloat>
@@ -58,28 +58,30 @@ using namespace std;
 class MuniAstrometryLayer
 {
 public:
-  MuniAstrometryLayer(int w, int h):ltic(10),gold(wxColour(255,215,0,240)),DarkOrange2(wxColour(238,118,0)),
-				    width(w),height(h),alpha(0.0),delta(0.0),xoff(0.0),yoff(0.0),scale(1.0),
-				    angle(0.0),maglim(18.0) {}
+  MuniAstrometryLayer(int w, int h):
+    ltic(10),gold(wxColour(255,215,0,240)),DarkOrange2(wxColour(238,118,0)),
+    width(w),height(h),alpha(0.0),delta(0.0),xoff(0.0),yoff(0.0),scale(1.0),
+    angle(0.0),reflex(1.0),maglim(18.0) {}
   MuniLayer GetLayer() const;
   bool IsEmpty() const { return objects.empty(); }
 
-  void SetProj(const wxString&,double,double,double,double,double,double);
+  void SetProj(const wxString&,double,double,double,double,double,double,
+	       double);
   void DrawStars(const FitsTable& table, const wxString&,const wxString&,
 		 const wxString&,const wxString&,const wxString&);
   void DrawCompas();
   void DrawMatch(double,const std::vector<double>&,const std::vector<double>&);
   void Draw3Space(int, const std::vector<int>&);
   void Draw3Tri(const std::vector<double>&,const std::vector<double>&);
-  
+
 private:
-  
+
   const int ltic;
   const wxColour gold,DarkOrange2;
   std::vector<wxObject *> objects;
   int width, height;
   wxString proj;
-  double alpha,delta,xoff,yoff,scale,angle,maglim;
+  double alpha,delta,xoff,yoff,scale,angle,reflex,maglim;
   wxBitmap tribit;
 
 
@@ -91,7 +93,7 @@ MuniLayer MuniAstrometryLayer::GetLayer() const
   return layer;
 }
 
-void MuniAstrometryLayer::SetProj(const wxString& t,double a,double d,double x,double y,double s,double f)
+void MuniAstrometryLayer::SetProj(const wxString& t,double a,double d,double x,double y,double s,double f, double z)
 {
   proj = t;
   alpha = a;
@@ -100,12 +102,16 @@ void MuniAstrometryLayer::SetProj(const wxString& t,double a,double d,double x,d
   yoff = y;
   scale = s;
   angle = f;
+  reflex = z;
   //wxLogDebug(proj+" %f %f %f %f %f %f",a,d,x,y,s,f);
 }
 
-void MuniAstrometryLayer::DrawStars(const FitsTable& table,const wxString& label_ra,
-				    const wxString& label_dec, const wxString& label_pmra,
-				    const wxString& label_pmdec,const wxString& label_mag)
+void MuniAstrometryLayer::DrawStars(const FitsTable& table,
+				    const wxString& label_ra,
+				    const wxString& label_dec,
+				    const wxString& label_pmra,
+				    const wxString& label_pmdec,
+				    const wxString& label_mag)
 {
   objects.push_back(new MuniDrawPen(wxPen(gold,1.0)));
   objects.push_back(new MuniDrawFont(*wxNORMAL_FONT,gold));
@@ -127,37 +133,46 @@ void MuniAstrometryLayer::DrawStars(const FitsTable& table,const wxString& label
       const double *a = table.GetColumn(label_ra).GetCol_double();
       const double *d = table.GetColumn(label_dec).GetCol_double();
       const float *mag = imag >= 0 ? table.GetColumn(label_mag).GetCol_float() : 0;
-      double *ppma = ipmra  >= 0 ? 
+      double *ppma = ipmra  >= 0 ?
 	(double *)table.GetColumn(label_pmra).GetCol_double() : 0;
-      double *ppmd = ipmdec >= 0 ? 
+      double *ppmd = ipmdec >= 0 ?
 	(double *)table.GetColumn(label_pmdec).GetCol_double() : 0;
 
       objects.push_back(new MuniDrawPen(wxPen(gold,1.8)));
       objects.push_back(new MuniDrawBrush(wxColour(90,90,255,190)));
 
-      FitsProjection pr(proj,alpha,delta,xoff,yoff,scale,angle);
+      FitsProjection pr(proj,alpha,delta,xoff,yoff,scale,angle,reflex);
 
       double dt = 2012.8 - 2000.0;
       //      dt = 0.0;
 
       for(int i = 0; i < n; i++) {
 
-	double x,y;
-	double pma = ppma ? dt*ppma[i]/3600000.0 : 0.0;
-	double pmd = ppmd ? dt*ppmd[i]/3600000.0 : 0.0;
+	if( wxFinite(a[i]) && wxFinite(d[i]) && wxFinite(ppma[i]) &&
+	    wxFinite(ppmd[i]) && wxFinite(mag[i]) ) {
 
-	//	printf("pm: %f %f %f %f %f %f\n",a[i],d[i],pma,pmd,ppma[i],ppmd[i]);
+	  double x,y;
+	  double pma = ppma ? dt*ppma[i]/3600000.0 : 0.0;
+	  double pmd = ppmd ? dt*ppmd[i]/3600000.0 : 0.0;
 
-	pr.ad2xy(a[i]+pma,d[i]+pmd,x,y);
+	  //wxPrintf("pm: %f %f %f %f %f %f\n",a[i],d[i],pma,pmd,ppma[i],ppmd[i]);
 
-	if( mag ) {
-	  double r = 1.5*pow(10.0,0.11*(maglim - mag[i]));
-	  //	  double r = 3.0*pow(maglim - mag[i],0.333);
-	  //	  if( mag[i] > 1.0 )
-	  objects.push_back(new MuniDrawCircle(x,y,r));
+	  pr.ad2xy(a[i]+pma,d[i]+pmd,x,y);
+
+	  //wxLogDebug("a,d: %f %f, x,y: %f %f",a[i]+pma,d[i]+pmd,x,y);
+
+	  if( 0 < x && x < width && 0 < y && y < width ) {
+	    if( mag ) {
+	      double r = 1.5*pow(10.0,0.11*(maglim - mag[i]));
+	      //	  double r = 3.0*pow(maglim - mag[i],0.333);
+	      //	  if( mag[i] > 1.0 )
+	      //	  wxLogDebug("%f %f %f",x,y,r);
+	      objects.push_back(new MuniDrawCircle(x,y,r));
+	    }
+	    else
+	      objects.push_back(new MuniDrawCircle(x,y,1.0));
+	  }
 	}
-	else
-	  objects.push_back(new MuniDrawCircle(x,y,1.0));
       }
     }
   }
@@ -203,9 +218,9 @@ void MuniAstrometryLayer::DrawCompas()
     double f = 90.0*i - angle;
     double r1 = 3.0*ltic;
     double r2 = rrose - 4.0*ltic;
-    double x1 = xoff + r1*cos(f/rad);
+    double x1 = xoff + r1*cos(f/rad)*reflex;
     double y1 = yoff + r1*sin(f/rad);
-    double x2 = xoff + r2*cos(f/rad);
+    double x2 = xoff + r2*cos(f/rad)*reflex;
     double y2 = yoff + r2*sin(f/rad);
     objects.push_back(new MuniDrawLine(x1,y1,x2,y2));
     objects.push_back(new MuniDrawText(x2,y2,cp[i]));
@@ -318,9 +333,10 @@ void MuniAstrometryLayer::Draw3Tri(const std::vector<double>& u, const std::vect
 
 // --- MuniAstrometry
 
-MuniAstrometry::MuniAstrometry(wxWindow *w, MuniConfig *c): 
-  wxDialog(w,wxID_ANY,"Astrometry",wxDefaultPosition,wxDefaultSize,wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER),
-  config(c), 
+MuniAstrometry::MuniAstrometry(wxWindow *w, MuniConfig *c):
+  wxDialog(w,wxID_ANY,"Astrometry",wxDefaultPosition,wxDefaultSize,
+	   wxDEFAULT_DIALOG_STYLE|wxRESIZE_BORDER),
+  config(c),
   timer(this),pipe(this),
   nhist(0),
   maglim(18.0),
@@ -430,15 +446,15 @@ void MuniAstrometry::CreateControls()
 
   // title
   wxBoxSizer *topsizer = new wxBoxSizer(wxVERTICAL);
-  
+
 
   wxNotebook *book = new wxNotebook(this,wxID_ANY);
-  
+
   wxPanel* manpanel = new wxPanel(book);
   wxBoxSizer *mansizer = new wxBoxSizer(wxVERTICAL);
-  
+
   wxStaticBoxSizer *psizer = new wxStaticBoxSizer(wxVERTICAL,manpanel,"Projection");
-  
+
   wxArrayString projections;
   projections.Add("Identity");
   projections.Add("Gnomonic");
@@ -492,9 +508,14 @@ void MuniAstrometry::CreateControls()
   ss->Add(new wxStaticText(manpanel,wxID_ANY,L"[°]"),cf);
   grid->Add(ss,cf);
 
+  ss = new wxBoxSizer(wxHORIZONTAL);
+  reflex_checkbox = new wxCheckBox(manpanel,wxID_ANY,"Reflex");
+  ss->Add(reflex_checkbox);
+  grid->Add(ss,cf);
+
   savebutt = new wxButton(manpanel,wxID_ANY,"Save to header");
   savebutt->Enable(false);
-  
+
   wxBoxSizer *st = new wxBoxSizer(wxHORIZONTAL);
   st->Add(grid,wxSizerFlags().Border().Center());
   st->Add(savebutt,wxSizerFlags().Border().Align(wxALIGN_RIGHT|wxALIGN_BOTTOM));
@@ -503,8 +524,8 @@ void MuniAstrometry::CreateControls()
 
   mansizer->Add(tsizer,wxSizerFlags().Expand().Border());
 
-  // accurate  
-  
+  // accurate
+
   overlayid = new wxStaticText(manpanel,wxID_ANY,"Overlay: "+astrolog.GetSign());
   overlay_check = new wxCheckBox(manpanel,wxID_ANY,"Draw");
   overlay_check->SetValue(draw_overlay);
@@ -598,7 +619,7 @@ void MuniAstrometry::CreateControls()
 
   topsizer->Add(book,wxSizerFlags(1).Expand().DoubleBorder());
 
-  wxStdDialogButtonSizer *buttsize = 
+  wxStdDialogButtonSizer *buttsize =
     static_cast<wxStdDialogButtonSizer *>(CreateButtonSizer(wxAPPLY|wxCANCEL));
 
   if( buttsize ) {
@@ -634,6 +655,8 @@ void MuniAstrometry::CreateControls()
   Bind(wxEVT_COMMAND_TEXT_UPDATED,&MuniAstrometry::OnTextDouble,this,wscale->GetId());
   Bind(wxEVT_COMMAND_TEXT_UPDATED,&MuniAstrometry::OnTextDouble,this,acenter->GetId());
   Bind(wxEVT_COMMAND_TEXT_UPDATED,&MuniAstrometry::OnTextDouble,this,dcenter->GetId());
+  Bind(wxEVT_COMMAND_CHECKBOX_CLICKED,&MuniAstrometry::OnReflex,this,
+       reflex_checkbox->GetId());
 
   Bind(wxEVT_COMMAND_TEXT_ENTER,&MuniAstrometry::OnTextDouble,this,wangle->GetId());
   Bind(wxEVT_COMMAND_TEXT_ENTER,&MuniAstrometry::OnTextDouble,this,wscale->GetId());
@@ -657,6 +680,7 @@ void MuniAstrometry::CreateControls()
   ids.push_back(catbutt->GetId());
   ids.push_back(refbutt->GetId());
   ids.push_back(rembutt->GetId());
+  ids.push_back(reflex_checkbox->GetId());
 }
 
 void MuniAstrometry::OnUpdateUI(wxUpdateUIEvent& e)
@@ -681,14 +705,15 @@ void MuniAstrometry::OnUpdateUI(wxUpdateUIEvent& e)
     init_file = false;
 
     Reset();
-    
-    if( array.GetWCS(xoff,yoff,alpha,delta,scale,angle) ) {
+
+    if( array.GetWCS(xoff,yoff,alpha,delta,scale,angle,reflex) ) {
 
       wscale->SetValue(Scale(scale));
       //      wangle->SetValue(Period(angle));
       wangle->SetValue(angle);
       acenter->SetValue(alpha);
       dcenter->SetValue(delta);
+      reflex_checkbox->SetValue(reflex < 0);
 
       init_par = true;
 
@@ -798,6 +823,7 @@ void MuniAstrometry::Reset()
   wangle->SetValue("0.0");
   acenter->SetValue("0.0");
   dcenter->SetValue("0.0");
+  reflex_checkbox->SetValue(false);
 
   if( array.IsOk() ) {
     wxASSERT(array.Naxis() == 2);
@@ -810,7 +836,7 @@ FitsTable MuniAstrometry::LoadCatalogue(const wxString& filename)
 {
 
   FitsTable table;
-  
+
   FitsFile fits(filename);
 
   if( fits.IsOk() ) {
@@ -819,12 +845,7 @@ FitsTable MuniAstrometry::LoadCatalogue(const wxString& filename)
       if( ! fits.IsOk() || fits.Hdu(i).Type() != HDU_TABLE ) continue;
 
       table = fits.Hdu(i);
-
-      // inform user
-      wxString a;
-      a.Printf("%d stars in list.",(int)table.Nrows());
-      wxLogDebug(a);
-
+      wxLogDebug("%d stars in list.",(int)table.Nrows());
     }
   }
 
@@ -837,7 +858,7 @@ void MuniAstrometry::InitByCatalogue(const FitsTable& catalogue)
   // finds coordinate keys
   int ira = catalogue.GetColIndex(label_ra);
   int idec = catalogue.GetColIndex(label_dec);
-  
+
   if( ! init_par && (ira >= 0 && idec >= 0) ) {
 
     double xx,yy,sx,sy;
@@ -849,31 +870,31 @@ void MuniAstrometry::InitByCatalogue(const FitsTable& catalogue)
 
 
     for(int i = 0; i < n; i++) {
-      
+
       double x = a[i];
       double y = d[i];
       xx = xx + x;
       yy = yy + y;
       sx = sx + x*x;
       sy = sy + y*y;
-      
+
     }
-	
+
     if( n > 0 ) {
-      
+
       alpha = xx/n;
       delta = yy/n;
-      
+
       acenter->SetValue(alpha);
       dcenter->SetValue(delta);
-      
+
       sx = sqrt(sx/n);
       //	sy = sqrt(sy/n);
       //	wxLogDebug("%f %d %f",sy,n,delta);
       sy = sqrt(sy/n - delta*delta);
-      
+
       double r = sy; // in declination, there is no scale contraction
-      
+
       if( yoff ) {
 	scale = yoff/r;
 	//	  wxLogDebug("%f %f %f",(float)alpha,(float)delta,(float)scale);
@@ -916,17 +937,18 @@ void MuniAstrometry::DrawOverlay(const FitsTable& t)
     ev.proj = proj;
     ev.scale = scale;
     ev.angle = angle;
+    ev.reflex = reflex;
     ev.xcen = xoff;
     ev.ycen = yoff;
     ev.acen = alpha;
     ev.dcen = delta;
     MuniAstrometryLayer l(array.Naxes(0),array.Naxes(1));
-    l.SetProj(proj,alpha,delta,xoff,yoff,scale,angle);
+    l.SetProj(proj,alpha,delta,xoff,yoff,scale,angle,reflex);
     l.DrawStars(t,label_ra,label_dec,label_pmra,label_pmdec,label_mag);
     if( page == 0 )
-      l.DrawCompas();
+     l.DrawCompas();
     ev.layer = l.GetLayer();
-    wxQueueEvent(GetParent(),ev.Clone()); 
+    wxQueueEvent(GetParent(),ev.Clone());
   }
   else {
     MuniAstrometryEvent ev(EVT_ASTROMETRY);
@@ -956,6 +978,12 @@ void MuniAstrometry::OnTextDouble(wxCommandEvent& event)
   edited = true;
 }
 
+void MuniAstrometry::OnReflex(wxCommandEvent& event)
+{
+  reflex = event.IsChecked() ? -1 : 1;
+  DrawOverlay(coverlay);
+  edited = true;
+}
 
 void MuniAstrometry::RunProcessing()
 {
@@ -964,7 +992,7 @@ void MuniAstrometry::RunProcessing()
   MuniProcess *astrometry = new MuniProcess(&pipe,"astrometry");
   astrometry->SetVerbose(false);
   pipe.push(astrometry);
-  
+
   astrometry->Write("PIPELOG = T");
   astrometry->Write("PROJECTION = '"+proj.Upper()+"'");
   astrometry->Write("WCSSAVE = T");
@@ -997,7 +1025,7 @@ void MuniAstrometry::RunProcessing()
     astrometry->Write("CAT = '"+catfile+"'");
   }
   else {
-    if( relative ) 
+    if( relative )
       astrometry->Write("REL = '"+reffile+"'");
     else
       astrometry->Write("REF = '"+reffile+"'");
@@ -1009,7 +1037,7 @@ void MuniAstrometry::OnCalibrate(wxCommandEvent& event)
 {
   Bind(wxEVT_END_PROCESS,&MuniAstrometry::OnCalibrateFinish,this);
   Bind(wxEVT_TIMER,&MuniAstrometry::OnTimer,this);
-  
+
   wxBeginBusyCursor();
 
   calbutt->Hide();
@@ -1093,7 +1121,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
       wxString value(re.GetMatch(out[idx],2));
 
       if( key == "ASTROMETRY" ) {
-      
+
 	if( value.Find("Start") != wxNOT_FOUND ) {
 	  progress->SetValue(0);
 	  proginfo->SetLabel("Starting...");
@@ -1110,7 +1138,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
       else if( key == "ASTROFIT" ) {
 
 	if( value.Find("Start") != wxNOT_FOUND ) {
-	  
+
 	}
 	else if( value.Find("Final") != wxNOT_FOUND ) {
 
@@ -1130,6 +1158,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 	    wangle->SetValue(angle);
 	    acenter->SetValue(alpha);
 	    dcenter->SetValue(delta);
+	    //	    reflex_checkbox->SetValue();
 
 	    wxString a;
 	    a.Printf(" Success (RMS = %.2f "+astropt->GetOutputUnits()+")",
@@ -1142,7 +1171,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 	  }
 	}
       }
-      
+
       else if( key == "ASTROMATCH" ) {
 
 	if( value.Find("Start") != wxNOT_FOUND ) {
@@ -1182,7 +1211,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 
       }
       else if( key == "AFIT" || key == "RFIT" || key == "MFIT" ) {
-	
+
 	afit = true;
 
 	wxStringInputStream ss(value);
@@ -1190,7 +1219,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 
 	double xcen,ycen;
 	t >> s0 >> scale >> angle >> alpha >> delta >> xcen >> ycen;
-      } 
+      }
 
 
       else if( key == "MPROGRESO" ) {
@@ -1200,7 +1229,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 
 	int ns, ntot;
 	t >> ns >> ntot;
-	
+
 	double r = double(ns)/double(ntot);
 
 	wxDateTime now;
@@ -1217,13 +1246,13 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 	  double vel = r/sec.ToDouble(); // velocity in fractions per second
 	  wxLongLong est;
 	  est.Assign((1 - r)/vel);
-	  
+
 	  wxTimeSpan dt = wxTimeSpan::Seconds(est);
 	  int d = dt.GetDays();
 	  int h = dt.GetHours();
 	  int m = dt.GetMinutes();
 	  wxLongLong s = dt.GetSeconds();
-	  
+
 	  //	  wxLogDebug("%d %d %d "+s.ToString(),d,h,m);
 
 	  wxString ss;
@@ -1284,7 +1313,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 
 	x.clear(); y.clear();
 	if( n > 0 ) {
-	  x.resize(n); y.resize(n); 
+	  x.resize(n); y.resize(n);
 	  for(int i = 0; i < n; i++)
 	    t >> x[i] >> y[i];
 	}
@@ -1293,7 +1322,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
 	t >> m;
 	u.clear(); v.clear();
 	if( m > 0 ) {
-	  u.resize(m); v.resize(m); 
+	  u.resize(m); v.resize(m);
 	  for(int i = 0; i < m; i++)
 	    t >> u[i] >> v[i];
 	}
@@ -1314,7 +1343,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
       }
 
       else if( key == "MTRI" ) {
-	
+
 	wxStringInputStream ss(value);
 	wxTextInputStream t(ss);
 
@@ -1346,9 +1375,9 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
       ev.acen = alpha;
       ev.dcen = delta;
     }
-    layer.SetProj(proj,alpha,delta,xoff,yoff,scale,angle);
+    layer.SetProj(proj,alpha,delta,xoff,yoff,scale,angle,reflex);
     //    layer.DrawStars(catalogue,label_ra,label_dec,label_pmra,label_pmdec,label_mag);
-    
+
     layer.Draw3Tri(u,v);
 
     if( x.size() > 0 ) {
@@ -1356,7 +1385,7 @@ void MuniAstrometry::ParseProcessing(const wxArrayString& out)
     }
     if( ! layer.IsEmpty() ) {
       ev.layer = layer.GetLayer();
-      wxQueueEvent(GetParent(),ev.Clone()); 
+      wxQueueEvent(GetParent(),ev.Clone());
     }
   }
 
@@ -1377,7 +1406,7 @@ void MuniAstrometry::OnSaveWCS(wxCommandEvent& event)
 
   MuniProcess *action = new MuniProcess(&pipe,"wcsupdate");
   pipe.push(action);
- 
+
   action->Write("WCSSAVE = T");
   action->Write("PROJECTION = '"+proj.Upper()+"'");
 
@@ -1417,7 +1446,7 @@ void MuniAstrometry::OnRemove(wxCommandEvent& event)
 
   MuniProcess *action = new MuniProcess(&pipe,"wcsremove");
   pipe.push(action);
-  
+
   action->Write("WCSSAVE = T");
   action->WriteFile(workingfile);
 
@@ -1453,7 +1482,7 @@ double MuniAstrometry::Scale(double s) const
     return 3600.0/s;
   else if( sunit->GetLabel() == ARC_MIN )
     return 60.0/s;
-  else 
+  else
     return s;
 }
 
@@ -1496,14 +1525,14 @@ void MuniAstrometry::OnReference(wxCommandEvent& event)
     EraseTemp();
 
     if( ms.GetType() == ID_ASTRO_CAT ) {
-      
+
       tmpcat = ms.IsTemporary();
       if( tmpcat ) {
 	catfile = wxFileName::CreateTempFileName("xmunipack-astrometry_");
 	wxCopyFile(ms.GetPath(),catfile);
       }
       else
-	catfile = ms.GetPath();	
+	catfile = ms.GetPath();
       label_ra = ms.GetLabelRA();
       label_dec = ms.GetLabelDec();
       label_pmra = ms.GetLabelPMRA();
@@ -1511,7 +1540,7 @@ void MuniAstrometry::OnReference(wxCommandEvent& event)
       label_mag = ms.GetLabelMag();
       refcatid->SetLabel(ms.GetId());
       catalogue = LoadCatalogue(catfile);
-      if( init_par ) 
+      if( init_par )
 	InitByCatalogue(catalogue);
       if( ! coverlay.IsOk() ) {
 	overlayid->SetLabel(ms.GetId());
@@ -1553,4 +1582,3 @@ void MuniAstrometry::OnBookChange(wxBookCtrlEvent& event)
     tip.ShowFor(calbutt);
   }
 }
-
