@@ -2,7 +2,7 @@
 
   xmunipack - display canvas
 
-  Copyright © 2012-14 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-14, 17 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -10,12 +10,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -102,7 +102,7 @@ void MuniDisplayCanvas::OnClose(wxCloseEvent& event)
 
 void MuniDisplayCanvas::OnScroll(wxScrollWinEvent& event)
 {
-  rendering = true;  
+  rendering = true;
   event.Skip();
 }
 
@@ -142,6 +142,7 @@ void MuniDisplayCanvas::OnSize(wxSizeEvent& event)
 
 void MuniDisplayCanvas::OnPaint(wxPaintEvent& event)
 {
+  //  wxLogDebug("OnPaint");
   wxPaintDC dc(this);
 
   /*
@@ -184,7 +185,7 @@ void MuniDisplayCanvas::OnPaint(wxPaintEvent& event)
       int yb = wxMax(yw/z,0);
       int wb = wxMin(ww/z + 1,icon.GetWidth());
       int hb = wxMin(hw/z + 1,icon.GetHeight());
-      
+
       bool wt = 0 < wb && wb <= icon.GetWidth();
       bool ht = 0 < hb && hb <= icon.GetHeight();
       bool xt = xb >= 0 && xb + wb <= icon.GetWidth();
@@ -229,12 +230,10 @@ void MuniDisplayCanvas::OnPaint(wxPaintEvent& event)
     upd++;
   }
 
-
-  //  for(size_t i = 0; i < layers.size(); i++)
-  list<MuniLayer>::const_iterator i = layers.begin();
+  // Layers
+  list<MuniLayer>::const_iterator i;
   for(i = layers.begin(); i != layers.end(); ++i)
     DrawLayer(dc,*i);
-  //    DrawLayer(dc,layers[i]);
 
 }
 
@@ -324,22 +323,20 @@ void MuniDisplayCanvas::InitDC(int w0, int h0, double z)
   int hv = wxMax(h,hc);
 
   SetVirtualSize(wv,hv);
-  
-  xoff = wxMax((wv - w)/2,0);
-  yoff = wxMax((hv - h)/2,0);
-
-  //  wxLogDebug("%d %d %d %d %f",w,h,xoff,yoff,z);
 
   if( z > 1.0 )
     canvas = wxImage(w0,h0);
   else
     canvas = wxImage(w,h);
 
+  xoff = wxMax((wc - canvas.GetWidth())/2,0);
+  yoff = wxMax((hc - canvas.GetHeight())/2,0);
+  //  wxLogDebug("%d %d %d %d %f",w,h,xoff,yoff,z);
+
   canvas.InitAlpha();
   for(int i = 0; i < canvas.GetWidth(); i++)
     for(int j = 0; j < canvas.GetHeight(); j++)
       canvas.SetAlpha(i,j,wxIMAGE_ALPHA_TRANSPARENT);
-
 }
 
 
@@ -412,26 +409,26 @@ void MuniDisplayCanvas::Render()
     h = wxMin(hs,fitsimage.GetHeight());
     y = 0;
   }
-    
+
   x = 0;
   y = 0;
   w = fitsimage.GetWidth();
   h = fitsimage.GetHeight();
-  
+
   wxASSERT(zoom > 0.0);
 
-  if( xoff > 0 ) 
+  if( xoff > 0 )
     x = 0;
   else
     x = wxMax(x0,0)/zoom;
 
-  if( yoff > 0 ) 
+  if( yoff > 0 )
     y = 0;
   else
     y = wxMax(fitsimage.GetHeight() - (hs + y0)/zoom,0);
+
   w = wxMin(fitsimage.GetWidth(),ws/zoom);
   h = wxMin(fitsimage.GetHeight(),hs/zoom);
-  
 
   //  wxLogDebug("%f %d %d %d %d %d %d %d %d %d %d",zoom,x,y,w,h,x0,y0,wc,hc,xoff,yoff);
 
@@ -468,7 +465,7 @@ void MuniDisplayCanvas::OnSubRender(MuniRenderEvent& event)
 	canvas.SetRGB(wxRect(k,l,1,1),img.GetRed(i,j),img.GetGreen(i,j),img.GetBlue(i,j));
 	canvas.SetAlpha(k,l,wxIMAGE_ALPHA_OPAQUE);
       }
-    }  
+    }
   Refresh();
 }
 
@@ -509,7 +506,7 @@ void MuniDisplayCanvas::StopRendering()
   }
 }
 
-void MuniDisplayCanvas::ConvertCoo(double u, double v, double& x, double&y)
+void MuniDisplayCanvas::ConvertCoo(double u, double v, double& x, double& y)
 {
   double height = canvas.GetHeight();
   if( zoom > 1.0 ) height = zoom*height;
@@ -518,11 +515,18 @@ void MuniDisplayCanvas::ConvertCoo(double u, double v, double& x, double&y)
   y = yoff + height - zoom*v;
   x = x - vbX;
   y = y - vbY;
+
+  /*
+  x = u;
+  y = height - v;
+  */
 }
 
 void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 {
+  //  wxLogDebug("DrawLayer");
   //  wxStopWatch sw;
+  //DoPrepareDC(dc);
 
   double height = canvas.GetHeight();
 
@@ -550,7 +554,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 	float y = yoff + (height - zoom*circle->y);
 	dc.DrawCircle(x,y,d);
       }
-	
+
       MuniDrawLine *line = dynamic_cast<MuniDrawLine *>(*i);
       if( line ) {
 	wxPoint2DDouble points[2];
@@ -563,13 +567,13 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
       MuniDrawText *text = dynamic_cast<MuniDrawText *>(*i);
       if( text ) {
 	dc.DrawText(text->text,zoom*text->x,height-zoom*text->y);
-      }	
+      }
     }
 
   }
   */
 
-  //  wxLogDebug("%f %f %f %d %d %d ",(float)xoff,(float)yoff,(float)zoom,vbX,vbY,height);
+  //  wxLogDebug("%f %f %f %f %f %f ",(float)xoff,(float)yoff,(float)zoom,(float)vbX,(float)vbY,height);
 
   wxGraphicsContext *gc = wxGraphicsContext::Create(dc);
   if( gc ) {
@@ -587,6 +591,8 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
     //    gc->SetBrush(wxBrush(wxColour(90,90,255,130)));
     //    gc->SetBrush(*wxBLUE_BRUSH);
     //    gc->SetPen(wxPen(*wxWHITE,1));
+    //    gc->DrawEllipse(100.0,100.0,100.0,100.0);
+
 
     vector<wxObject *>::const_iterator i;
     vector<wxObject *> objects = layer.GetObjects();
@@ -603,16 +609,17 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 
       MuniDrawCircle *circle = dynamic_cast<MuniDrawCircle *>(*i);
       if( circle ) {
-	double d = 2.0*circle->r/**zoom*/;
+	double r = wxMax(circle->r * zoom,2);
+	double d = 2*r;
+
 	double x,y;
 	ConvertCoo(circle->x,circle->y,x,y);
-	x = x - circle->r;
-	y = y - circle->r;
-	//	double x = xoff + zoom*circle->x - circle->r;
-	//	double y = yoff + height - zoom*circle->y - circle->r;
+	//wxLogDebug("%f %f %f %f",x,y,circle->r,d);
+	x = x - r;
+	y = y - r;
 	gc->DrawEllipse(x,y,d,d);
       }
-	
+
       MuniDrawLine *line = dynamic_cast<MuniDrawLine *>(*i);
       if( line ) {
 	wxPoint2DDouble points[2];
@@ -621,6 +628,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 	points[0] = wxPoint2DDouble(x,y);
 	ConvertCoo(line->x2,line->y2,x,y);
 	points[1] = wxPoint2DDouble(x,y);
+	//	wxLogDebug("%f %f %f %f %f %f",line->x1,line->y1,line->x2,line->y2,x,y);
 	/*
 	points[0] = wxPoint2DDouble(xoff+zoom*line->x1,yoff+height-zoom*line->y1);
 	points[1] = wxPoint2DDouble(xoff+zoom*line->x2,yoff+height-zoom*line->y2);
@@ -679,16 +687,16 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 	double x,y;
 	ConvertCoo(bitmap->x,bitmap->y-bitmap->h,x,y);
 	gc->DrawBitmap(bitmap->bitmap,x,y,bitmap->w,bitmap->h);
-	
+
 	//	gc->DrawBitmap(bitmap->bitmap,xoff+bitmap->x,yoff+(height-bitmap->y-bitmap->h),bitmap->w,bitmap->h);
       }
-	
+
     }
 
     gc->EndLayer();
     delete gc;
-  }  
- 
+  }
+
 
   //  wxLogDebug("Drawing took: %f sec",sw.Time()/1000.0);
 }
@@ -699,7 +707,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 
 //   wxGraphicsContext *gc = wxGraphicsContext::Create(dc);
 //   if( gc ) {
-    
+
 //     // default colors
 //     gc->SetBrush(wxBrush(*wxBLUE));
 //     gc->SetPen(wxPen(*wxYELLOW,1));
@@ -714,7 +722,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 
 // 	wxXmlAttribute *prop = child->GetAttributes();
 // 	while(prop) {
-	    
+
 // 	  wxString a = prop->GetValue();
 // 	  double x;
 // 	  a.ToDouble(&x);
@@ -731,7 +739,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 // 	  prop = prop->GetNext();
 // 	}
 // 	gc->StrokeLine(x1,y1,x2,y2);
-	 
+
 //       }
 
 //       else if( child->GetName() == "text") {
@@ -752,7 +760,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 // 	    y = t;
 
 // 	  prop = prop->GetNext();
-// 	}	  
+// 	}
 
 // 	gc->DrawText(text,x,y);
 //       }
@@ -776,7 +784,7 @@ void MuniDisplayCanvas::DrawLayer(wxPaintDC& dc, const MuniLayer& layer)
 // 	    r = x;
 
 // 	  prop = prop->GetNext();
-// 	}	  
+// 	}
 
 // 	gc->DrawEllipse(cx-r/2.0,cy-r/2.0,r,r);
 //       }
@@ -809,16 +817,16 @@ void MuniDisplayCanvas::OnMouseMotion(wxMouseEvent& event)
     //    wxLogDebug("%d %d %d %d",evt.i_x,evt.i_y,evt.z_x,evt.z_y);
 
     int size = config->detail_zoom;
-    
+
     int x = evt.i_x;
     int y = evt.i_y;
-    
+
     int x1 = x - size/2;
     int y1 = y - size/2;
     int x2 = x + size/2;
     int y2 = y + size/2;
 
-    if( fitsimage.IsOk() && 
+    if( fitsimage.IsOk() &&
 	x1 > 0 && y1 > 0 && x2 < fitsimage.GetWidth() && y2 < fitsimage.GetHeight() ){
       evt.picture = display.GetImage(fitsimage.GetSubImage(x1,y1,size,size));
     }
@@ -830,7 +838,7 @@ void MuniDisplayCanvas::OnMouseMotion(wxMouseEvent& event)
 
 
     if( ! dragging ) {
-    
+
       SetCursor(wxCursor(wxCURSOR_HAND));
       xdrag0 = event.GetLogicalPosition(dc).x;
       ydrag0 = event.GetLogicalPosition(dc).y;
@@ -911,7 +919,7 @@ void MuniDisplayCanvas::OnKeyDown(wxKeyEvent& event)
   }
 
   if( keycode == WXK_ESCAPE ) {
-    StopRendering(); 
+    StopRendering();
     return;
   }
 
@@ -929,7 +937,7 @@ void MuniDisplayCanvas::OnKeyDown(wxKeyEvent& event)
       case WXK_RIGHT:           id = wxID_FORWARD;  break;
       }
     }
-      
+
     if( id != wxID_ANY ) {
       wxQueueEvent(topwin,new wxCommandEvent(wxEVT_COMMAND_MENU_SELECTED,id));
       return;
@@ -940,9 +948,9 @@ void MuniDisplayCanvas::OnKeyDown(wxKeyEvent& event)
   long y = event.GetY();
 
   switch(keycode) {
-  case WXK_LEFT: 
+  case WXK_LEFT:
     x--; break;
-  case WXK_UP: 
+  case WXK_UP:
     y--; break;
   case WXK_RIGHT:
     x++; break;
@@ -1057,11 +1065,11 @@ void MuniDisplayCanvas::OnAstrometry(MuniAstrometryEvent& e)
   */
 
   astrometry = e.astrometry;
-  //  layers.clear();
+  layers.clear();
 
   if( astrometry ) {
 
-    //  wxLogDebug(e.proj+" %f %f %f",e.xcen,e.ycen,e.scale);
+    //wxLogDebug(e.proj+" %f %f %f",e.xcen,e.ycen,e.scale);
 
     aangle = e.angle;
     ascale = e.scale;
@@ -1071,7 +1079,8 @@ void MuniDisplayCanvas::OnAstrometry(MuniAstrometryEvent& e)
     ycen = e.ycen;
     //  layers.push_back(e.svg);
     layers.push_back(e.layer);
-    //  wxLogDebug("%d",(int)e.layer.objects.size());
+//    wxLogDebug("astrometryevent: %d",(size_t)e.layer.objects.size());
+//    wxLogDebug("astrometryevent: %d",(size_t)e.layer.IsEmpty());
   }
 
   Refresh();
@@ -1083,7 +1092,7 @@ void MuniDisplayCanvas::OnPhotometry(MuniPhotometryEvent& e)
 
   if( e.erase )
     RemoveLayers(ID_PHOTOMETRY);
-  else 
+  else
     layers.push_back(e.layer);
 
   Refresh();
@@ -1162,7 +1171,7 @@ void MuniDisplayCanvas::OverlayBitmap(const vector<MuniDrawBase *>& drawobj)
 
   wxGraphicsContext *gc = wxGraphicsContext::Create(mdc);
   if( gc ) {
-    
+
     gc->SetBrush(wxBrush(*wxBLUE));
     gc->SetPen(wxPen(*wxYELLOW,1));
 
@@ -1184,9 +1193,9 @@ void MuniDisplayCanvas::OverlayBitmap(const vector<MuniDrawBase *>& drawobj)
 
   wxImage i = layer.ConvertToImage();
   i.SetMaskColour(0,0,0);
-  
+
   overlay.push_back(wxBitmap(i));
-  
+
 }
 */
 
@@ -1203,7 +1212,7 @@ void MuniDisplayCanvas::OverlayBitmap(const vector<MuniDrawBase *>& drawobj)
 
   // wxGraphicsContext *gc = wxGraphicsContext::Create(mdc);
   // if( gc ) {
-    
+
   //   gc->SetBrush(wxBrush(*wxBLUE));
   //   gc->SetPen(wxPen(*wxYELLOW,1,wxPENSTYLE_SOLID));
 
@@ -1215,7 +1224,7 @@ void MuniDisplayCanvas::OverlayBitmap(const vector<MuniDrawBase *>& drawobj)
   //   /*
   //   vector<wxGraphicsPath>::const_iterator i;
   //   for(i = paths.begin(); i != paths.end(); ++i) {
-  //   */      
+  //   */
 
   //   gc->StrokePath(path);
 
@@ -1225,19 +1234,19 @@ void MuniDisplayCanvas::OverlayBitmap(const vector<MuniDrawBase *>& drawobj)
 
   // wxImage i = layer.ConvertToImage();
   // i.SetMaskColour(0,0,0);
-  
+
   // overlay.push_back(wxBitmap(i));
-  
+
  //}
 
 
 
 // ---- ImageRender ---------------------------------
 
-ImageRender::ImageRender(wxEvtHandler *eh, const FitsImage& fi, 
-			 const FitsImage& fis, const FitsDisplay& d, 
+ImageRender::ImageRender(wxEvtHandler *eh, const FitsImage& fi,
+			 const FitsImage& fis, const FitsDisplay& d,
 			 double zz, bool z, int x, int y, int w, int h):
-  wxThread(wxTHREAD_DETACHED),handler(eh),fitsimage(fi), fimage(fis), 
+  wxThread(wxTHREAD_DETACHED),handler(eh),fitsimage(fi), fimage(fis),
   display(d), zoom(zz), zooming(z),x0(x),y0(y),width(w),height(h)
 {
   wxASSERT(handler && fitsimage.IsOk() && x >= 0 && y >= 0 && h > 0 && w > 0);
@@ -1261,7 +1270,7 @@ wxThread::ExitCode ImageRender::Entry()
 
 #ifdef __WXDEBUG__
   wxStopWatch sw;
-#endif  
+#endif
 
   // length of square side
   // This value is choosed to be the duration of a single iteration
@@ -1281,7 +1290,7 @@ wxThread::ExitCode ImageRender::Entry()
     newimage = fitsimage;//.GetSubImage(x0,y0,width,height);
     //    newimage.Rescale(zoom);
   }
-    
+
 
   //  wxLogDebug("Init took: %d msec",(int)sw.Time());
 
@@ -1321,7 +1330,7 @@ wxThread::ExitCode ImageRender::Entry()
 
       //      wxASSERT(w > i && h > j);
 
-      //      wxASSERT(x0 <= i && i < 
+      //      wxASSERT(x0 <= i && i <
       dx = wxMin(imax - i,side);
       dy = wxMin(jmax - j,side);
 
@@ -1329,7 +1338,7 @@ wxThread::ExitCode ImageRender::Entry()
       wxASSERT(dx > 0 && dy > 0 && fimage.IsOk());
 
       FitsImage sub(fimage.GetSubImage(i,j,dx,dy));
-      
+
       if( zooming ) {
 	FitsImage z(sub.Scale(zoom));
 	sub = z;
@@ -1341,7 +1350,7 @@ wxThread::ExitCode ImageRender::Entry()
       //      wxLogDebug("sub: %d %d %d %d",x,y,newimage.GetWidth(),newimage.GetHeight());
       wxASSERT(sub.IsOk());
       //      newimage.SetSubImage(x,y,sub);
-      
+
       wxASSERT(sub.IsOk());
 
       MuniRenderEvent ev(EVT_RENDER,ID_SUBRENDER);
@@ -1379,4 +1388,3 @@ wxThread::ExitCode ImageRender::Entry()
   //  wxLogDebug("Rendering took: %f sec",sw.Time()/1000.0);
   return (wxThread::ExitCode) 0;
 }
-
