@@ -2,7 +2,7 @@
 
   xmunipack - fits implementation
 
-  Copyright © 1997 - 2014 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 1997 - 2014, 2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -10,12 +10,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -48,7 +48,7 @@ using namespace std;
 // * 2d color (3d, unique sizes, header with CSPACE keyword)
 // * 3d (3d spectrum) ?
 // * multilayer (more layers, arbitrary sizes)
-// 
+//
 
 
 
@@ -75,11 +75,11 @@ wxString FitsHeader::Bitpix_str() const
   case 16: return  "0 .. 65535";
   case 32: return  "0 .. 4294967296";
   case -32:return L"0 .. ± 10^38, 6 digits";
-  default: 
+  default:
     wxString a;
     a.Printf("Bitpix = %d",bitpix);
     return a;
-  } 
+  }
 }
 
 bool FitsHeader::ParseRecord(const wxString& record, wxString& key,
@@ -108,7 +108,7 @@ bool FitsHeader::ParseRecord(const wxString& record, wxString& key,
     }
     */
 
-    
+
     char *i1 = index(cval,'\'');
     char *i2 = rindex(cval,'\'');
     if( i1 != NULL && i2 != NULL && i1 != i2 ) {
@@ -120,7 +120,7 @@ bool FitsHeader::ParseRecord(const wxString& record, wxString& key,
 
     value = cval;
     value.Trim();
-    
+
 
     return true;
   }
@@ -187,17 +187,17 @@ wxString FitsHeader::Exposure_str(const wxString& key) const
 
 // ------ FitsHDU
 
-size_t FitsHdu::GetCount() const 
-{ 
-  return header.GetCount(); 
+size_t FitsHdu::GetCount() const
+{
+  return header.GetCount();
 }
 
-wxString FitsHdu::Item(size_t i) const 
-{ 
-  return header.Item(i); 
+wxString FitsHdu::Item(size_t i) const
+{
+  return header.Item(i);
 }
 
-wxString FitsHdu::GetKey(const wxString& a) const 
+wxString FitsHdu::GetKey(const wxString& a) const
 {
   return header.GetKey(a);
 }
@@ -216,28 +216,28 @@ double FitsHdu::GetKeyDouble(const wxString& key) const
   return l.ToDouble(&x) ? x : 0.0;
 }
 
-wxString FitsHdu::GetUnit(const wxString& a) const 
+wxString FitsHdu::GetUnit(const wxString& a) const
 {
   return header.GetUnit(a);
 }
 
-int FitsHdu::Bitpix() const 
-{ 
-  return header.Bitpix(); 
+int FitsHdu::Bitpix() const
+{
+  return header.Bitpix();
 }
 
-wxString FitsHdu::Bitpix_str() const 
-{ 
-  return header.Bitpix_str(); 
+wxString FitsHdu::Bitpix_str() const
+{
+  return header.Bitpix_str();
 }
 
 wxString FitsHdu::Exposure_str(const wxString& a) const
 {
-  return header.Exposure_str(a); 
+  return header.Exposure_str(a);
 }
 
-int FitsHdu::Type() const 
-{ 
+int FitsHdu::Type() const
+{
   return type;
 }
 
@@ -251,43 +251,43 @@ wxString FitsHdu::Type_str() const
   }
 }
 
-int FitsHdu::Flavour() const 
-{ 
-  return HDU_DUMMY; 
+int FitsHdu::Flavour() const
+{
+  return HDU_DUMMY;
 }
 
-wxString FitsHdu::Flavour_str() const 
-{ 
-  return wxEmptyString; 
+wxString FitsHdu::Flavour_str() const
+{
+  return wxEmptyString;
 }
 
-int FitsHdu::Naxis() const 
-{ 
+int FitsHdu::Naxis() const
+{
   return 0;
 }
 
-long FitsHdu::Naxes(int n) const 
-{ 
+long FitsHdu::Naxes(int n) const
+{
   return 0;
 }
 
 long FitsHdu::Width() const
-{ 
+{
   return Naxes(0);
 }
 
-long FitsHdu::Height() const 
-{ 
-  return Naxes(1); 
+long FitsHdu::Height() const
+{
+  return Naxes(1);
 }
 
 bool FitsHdu::IsOk() const
-{ 
-  return ! header.IsEmpty(); 
+{
+  return ! header.IsEmpty();
 }
 
 bool FitsHdu::IsColor() const
-{ 
+{
   return Naxis() == 3;
 }
 
@@ -296,11 +296,11 @@ wxString FitsHdu::GetExtname() const
   return GetKey("EXTNAME");
 }
 
-bool FitsHdu::GetWCS(double& xpix, double& ypix, double& alpha, double& delta, double& scale, double& angle) const
+bool FitsHdu::GetWCS(double& xpix, double& ypix, double& alpha, double& delta, double& scale, double& angle, double& reflex) const
 {
   // projection is silently ignored
   wxString type(GetKey("CTYPE1"));
-  
+
   if( type.IsEmpty() ) return false;
 
   xpix = GetKeyDouble("CRPIX1");
@@ -315,8 +315,9 @@ bool FitsHdu::GetWCS(double& xpix, double& ypix, double& alpha, double& delta, d
   cd21 = GetKeyDouble("CD2_1");
   cd22 = GetKeyDouble("CD2_2");
 
+  reflex = -cd11*cd22 >= 0 ? 1.0 : -1.0;
   scale = 1.0/sqrt(cd11*cd11 + cd12*cd12);
-  angle = (45.0/atan(1.0)) * atan2(cd12,cd22);
+  angle = (45.0/atan(1.0)) * atan2(cd21,cd22);
 
   return true;
 }
@@ -327,12 +328,12 @@ bool FitsHdu::GetWCS(double& xpix, double& ypix, double& alpha, double& delta, d
 
 FitsArrayData::FitsArrayData(): naxis(0),naxes(0),array(0) {}
 
-FitsArrayData::FitsArrayData(int n, long *ns, float *a): 
+FitsArrayData::FitsArrayData(int n, long *ns, float *a):
   naxis(n),naxes(ns),array(a) {}
 
 
-FitsArrayData::FitsArrayData(const FitsArrayData& copy) 
-{ 
+FitsArrayData::FitsArrayData(const FitsArrayData& copy)
+{
   wxFAIL_MSG("FitsArrayData ----- WE ARE REALY NEED COPY CONSTRUCTOR ---");
 }
 
@@ -343,17 +344,17 @@ FitsArrayData& FitsArrayData::operator = (const FitsArrayData& other)
 }
 
 
-FitsArrayData::~FitsArrayData() 
-{ 
-  delete[] naxes; 
-  delete[] array; 
+FitsArrayData::~FitsArrayData()
+{
+  delete[] naxes;
+  delete[] array;
 }
 
 
 FitsArray::FitsArray(): npixels(0) {}
 
 FitsArray::FitsArray(const FitsHdu& h, int n, long *ns, float *a): FitsHdu(h)
-{ 
+{
   wxASSERT( n >= 0 && ns && a );
   type = HDU_IMAGE;
 
@@ -369,7 +370,7 @@ FitsArray::FitsArray(const FitsHdu& h, int n, long *ns, float *a): FitsHdu(h)
 
 
 FitsArray::FitsArray(const FitsHdu& h): FitsHdu(h)
-{ 
+{
   wxASSERT(h.Type() == HDU_IMAGE && h.IsOk());
 
   FitsArrayData *data = static_cast<FitsArrayData *>(GetRefData());
@@ -426,13 +427,13 @@ int FitsArray::Naxis() const
 }
 
 long FitsArray::Naxes(int n) const
-{ 
+{
   FitsArrayData *data = static_cast<FitsArrayData *>(m_refData);
   wxASSERT(data);
 
-  if( 0 <= n && n < data->naxis ) 
-    return data->naxes[n]; 
-  else 
+  if( 0 <= n && n < data->naxis )
+    return data->naxes[n];
+  else
     return 0;
 }
 
@@ -508,7 +509,7 @@ float FitsGeometry::MeanRect(float x, float y, float w, float h)
 
   //  if( dx > 0 && dy > 0 )
   //    wxLogDebug(_("%d %d"),dx,dy);
-  
+
 //   int ww = i2 - i1 + 1;
 //   int hh = j2 - j1 + 1;
 //   ww = dx;
@@ -584,7 +585,7 @@ FitsArray FitsArray::Plane(int n) const
       npixels = npixels*m;
     }
   */
-  
+
   const FitsArrayData *data = static_cast<FitsArrayData *>(m_refData);
   wxASSERT(data);
   const float *array = data->array;
@@ -595,9 +596,9 @@ FitsArray FitsArray::Plane(int n) const
   //  for(int l = 0; l < Naxis(); l++)
   //    if( l != n )
   memcpy(a,array+n*npixels,npixels*sizeof(float));
-  
+
     //  for(int l = 0; l < npixels; l++) a[l] = 1;
-    
+
   return FitsArray(*this,np,ns,a);
 }
 
@@ -628,7 +629,7 @@ void FitsArrayStat::Statistics(int ndata)
     if( x < min ) min = x;
   }
   med = QMed(nd,d,nd/2+1);
- 
+
   // mad = median of absolute deviations
   int n = 0;
   int imax = Npixels() - bstep;
@@ -664,7 +665,7 @@ float FitsArrayStat::QMed(int n, float *a, int k)
       while( x < a[j] && j > l) j--;
 
       if( i <= j ) { w = a[i]; a[i] = a[j]; a[j] = w; i++; j--; }
-      
+
     } while ( i <= j );
 
     if( j < k ) l = i;
@@ -708,11 +709,11 @@ wxString FitsArray::Flavour_str() const
 
 // ----------    FitsTable
 
-FitsTableColumnData::FitsTableColumnData(): 
+FitsTableColumnData::FitsTableColumnData():
   typecode(0),nrows(0),otable(0),btable(0),stable(0),itable(0),
   ltable(0),ftable(0),dtable(0),ctable(0) {}
 
-FitsTableColumnData::FitsTableColumnData(int t, long n, float *d): 
+FitsTableColumnData::FitsTableColumnData(int t, long n, float *d):
   typecode(t),nrows(n),otable(0),btable(0),stable(0),itable(0),
   ltable(0),ftable(d),dtable(0),ctable(0) {}
 
@@ -720,7 +721,7 @@ FitsTableColumnData::FitsTableColumnData(int t, long n, int *d):
   typecode(t),nrows(n),otable(0),btable(0),stable(0),itable(d),
   ltable(0),ftable(0),dtable(0),ctable(0) {}
 
-FitsTableColumnData::FitsTableColumnData(int t, long n, char **d): 
+FitsTableColumnData::FitsTableColumnData(int t, long n, char **d):
   typecode(t),nrows(n),otable(0),btable(0),stable(0),itable(0),
   ltable(0),ftable(0),dtable(0),ctable(d) {}
 
@@ -762,10 +763,10 @@ FitsTableColumnData::~FitsTableColumnData()
 }
 
 
-FitsTableColumnData::FitsTableColumnData(const FitsTableColumnData& copy) 
-{ 
+FitsTableColumnData::FitsTableColumnData(const FitsTableColumnData& copy)
+{
   wxFAIL_MSG("FitsTableColumn ---- WE ARE REALY NEED COPY CONSTRUCTOR ----");
-  
+
 }
 
 FitsTableColumnData& FitsTableColumnData::operator = (const FitsTableColumnData& other)
@@ -780,56 +781,56 @@ FitsTableColumn::FitsTableColumn() {}
 FitsTableColumn::~FitsTableColumn() {}
 
 FitsTableColumn::FitsTableColumn(int t, long nr, float *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, double *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, long *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, int *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, short *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, char *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, bool *d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 FitsTableColumn::FitsTableColumn(int t, long nr, char **d)
-{ 
+{
   UnRef();
   SetRefData(new FitsTableColumnData(t,nr,d));
 }
 
 /*
 FitsTableColumn::FitsTableColumn(const FitsTableColumn& copy)
-{ 
+{
 }
 
 FitsTableColumn& FitsTableColumn::operator = (const FitsTableColumn& other)
@@ -839,15 +840,15 @@ FitsTableColumn& FitsTableColumn::operator = (const FitsTableColumn& other)
 }
 */
 
-int FitsTableColumn::GetColType() const 
-{ 
+int FitsTableColumn::GetColType() const
+{
   FitsTableColumnData *data = static_cast<FitsTableColumnData *>(m_refData);
   wxASSERT(data);
   return data->typecode;
 };
 
-long FitsTableColumn::Nrows() const 
-{ 
+long FitsTableColumn::Nrows() const
+{
   FitsTableColumnData *data = static_cast<FitsTableColumnData *>(m_refData);
   wxASSERT(data);
   return data->nrows;
@@ -942,7 +943,7 @@ wxObjectRefData *FitsTableColumn::CloneRefData(const wxObjectRefData *that) cons
     for(int i = 0; i < olddata->nrows; i++)
       newdata->ctable[i] = wxStrdup(olddata->ctable[i]);
   }
-  else 
+  else
     wxFAIL_MSG("FitsTableColumn::CloneRefData: Unknown data type.");
 
   return newdata;
@@ -961,19 +962,19 @@ FitsTableData::FitsTableData(const std::vector<FitsTableColumn>& cols): columns(
 // FitsTableData::FitsTableData(): ncols(0),columns(0) {}
 
 // /*
-// FitsTableData::FitsTableData(long nr, long nc, float *t): 
+// FitsTableData::FitsTableData(long nr, long nc, float *t):
 //   nrows(nr),ncols(nc),table(t) {}
 // */
 
-// FitsTableData::FitsTableData(long nc): ncols(nc) 
+// FitsTableData::FitsTableData(long nc): ncols(nc)
 // {
 //   columns = new FitsTableColumn[nc];
 //   for(int i = 0; i < nc; i++)
 //     columns[i] = 0;
 // }
 
-// FitsTableData::FitsTableData(const FitsTableData& copy) 
-// { 
+// FitsTableData::FitsTableData(const FitsTableData& copy)
+// {
 //   wxFAIL_MSG("FitsTableData ---- WE ARE REALY NEED COPY CONSTRUCTOR ----");
 // }
 
@@ -985,7 +986,7 @@ FitsTableData::FitsTableData(const std::vector<FitsTableColumn>& cols): columns(
 
 
 // FitsTableData::~FitsTableData()
-// { 
+// {
 //   delete[] columns;
 
 //   /*
@@ -1003,7 +1004,7 @@ FitsTableData::FitsTableData(const std::vector<FitsTableColumn>& cols): columns(
 //       delete[] a;
 //     }
 //   */
-    
+
 //     //    delete[] table[i];
 //   //  }
 //   //  delete[] typecode;
@@ -1057,12 +1058,12 @@ FitsTable::FitsTable(const FitsHdu& h, int ht, const vector<FitsTableColumn>& co
 }
 
 
-FitsTable::FitsTable(const FitsHdu& h): 
+FitsTable::FitsTable(const FitsHdu& h):
   FitsHdu(h),fits_type(h.Flavour())
   //  fits_type(static_cast<FitsTable>(h).fits_type)//,
   //  columns(static_cast<FitsTable>(h).columns)
   //  FitsHdu(h),fits_type(h.Flavour()),columns(static_cast<FitsTable>(h).columns)
-{ 
+{
   wxASSERT(h.Type() == HDU_TABLE && h.IsOk());
 
   //  wxLogDebug("FitsTable::FitsTable(const FitsHdu& h): ");
@@ -1115,8 +1116,8 @@ wxObjectRefData *FitsTable::CloneRefData(const wxObjectRefData *that) const
 //   newdata->columns = new FitsDataColumn[newdata->ncols];
 //   for(int i = 0; i < olddata->ncols; i++) {
 //     newdata->columns[i] = olddata->columns[i];
-  
-  
+
+
 
 //   /*
 //   int len = 1;
@@ -1145,11 +1146,11 @@ wxObjectRefData *FitsTable::CloneRefData(const wxObjectRefData *that) const
 //       table[i] = (void *) new float[olddata->nrows];
 //       memcpy(table,olddata->table[i],olddata->nrows*sizeof(float));
 //     }
-      
-    
+
+
 
 //   }
-  
+
 
 //   newdata->table = new void**[];
 
@@ -1342,14 +1343,14 @@ int FitsTable::GetColIndex(const wxString& label) const
 {
   for(size_t i = 0; i < GetCount(); i++) {
     wxString key,val,com;
-    
+
     FitsHeader::ParseRecord(Item(i),key,val,com);
-    
+
     if( label.StartsWith(val) ) {
 
       wxRegEx re("TTYPE([0-9]+)");
       wxASSERT(re.IsValid());
-    
+
       if( re.Matches(key) ) {
 	wxString a(re.GetMatch(key,1));
 	long i;
@@ -1368,7 +1369,7 @@ wxArrayString FitsTable::GetColLabels() const
 
   for(size_t i = 0; i < GetCount(); i++) {
     wxString key,val,com;
-    
+
     FitsHeader::ParseRecord(Item(i),key,val,com);
 
     if( key.StartsWith("TTYPE") )
@@ -1400,7 +1401,7 @@ void FitsTable::GetStarChart(wxOutputStream& output)
     float y = Pixel(1,i);
 
     float f = Pixel(11,i);
-    
+
     if( f > 0 ) {
       float r = wxMax(f/1e4,10.0);
       cout << "<circle cx=\"" << x << "\" cy=\"" << y
@@ -1459,7 +1460,7 @@ FitsFile::FitsFile(const wxString& name):
 
       if( naxis > 0 ) {
 
-	long *naxes = new long[naxis];  
+	long *naxes = new long[naxis];
 	fits_get_img_size(f,naxis,naxes,&stat);
 	if( stat ) { delete[] naxes; goto crash; }
 
@@ -1497,12 +1498,12 @@ FitsFile::FitsFile(const wxString& name):
       //      FitsTable table(head,htype,nrows,ncols);
       vector<FitsTableColumn> cols;
 
-      long frow = 1, felem = 1; 
+      long frow = 1, felem = 1;
       for(int k = 0; k < ncols; k++ ) {
 
 	int colnum = k + 1;
 	int typecode;
-	long repeat, width; 
+	long repeat, width;
 
 	fits_get_coltype(f,colnum,&typecode,&repeat,&width,&stat);
 	if( stat ) goto crash;
@@ -1515,49 +1516,49 @@ FitsFile::FitsFile(const wxString& name):
 	    a[i] = new char[width];
 	  char nullval[width];
 	  strcpy(nullval," ");
-	  fits_read_col(f,TSTRING,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TSTRING,colnum, frow, felem, nrows, &nullval,
 			a,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,a));
 	}
 	else if( typecode == TLOGICAL ) {
 	  bool *b = new bool[nrows];
 	  bool nullval = false;
-	  fits_read_col(f,TLOGICAL,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TLOGICAL,colnum, frow, felem, nrows, &nullval,
 			b,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,b));
 	}
 	else if( typecode == TBYTE || typecode == TBIT ) {
 	  char *b = new char[nrows];
 	  char nullval = 0;
-	  fits_read_col(f,TBYTE,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TBYTE,colnum, frow, felem, nrows, &nullval,
 			b,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,b));
 	}
 	else if( typecode == TSHORT ) {
 	  short *d = new short[nrows];
 	  short nullval = 0;
-	  fits_read_col(f,TSHORT,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TSHORT,colnum, frow, felem, nrows, &nullval,
 			d,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,d));
 	}
 	else if( typecode == TLONG || typecode == TINT32BIT ) {
 	  long *d = new long[nrows];
 	  long nullval = 0;
-	  fits_read_col(f,TLONG,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TLONG,colnum, frow, felem, nrows, &nullval,
 			d,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,d));
 	}
 	else if( typecode == TFLOAT ) {
 	  float *d = new float[nrows];
 	  float nullval = 0.0;
-	  fits_read_col(f,TFLOAT,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TFLOAT,colnum, frow, felem, nrows, &nullval,
 			d,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,d));
 	}
 	else if( typecode == TDOUBLE ) {
 	  double *d = new double[nrows];
 	  double nullval = 0.0;
-	  fits_read_col(f,TDOUBLE,colnum, frow, felem, nrows, &nullval, 
+	  fits_read_col(f,TDOUBLE,colnum, frow, felem, nrows, &nullval,
 			d,&dummy,&stat);
 	  cols.push_back(FitsTableColumn(typecode,nrows,d));
 	}
@@ -1565,7 +1566,7 @@ FitsFile::FitsFile(const wxString& name):
 	  wxLogDebug("FitsFile::FitsFile: The type code `%d' not implemented yet.",typecode);
 
 	/*
-	fits_read_col(f, TFLOAT,colnum, frow, felem, nrows, &nullval, 
+	fits_read_col(f, TFLOAT,colnum, frow, felem, nrows, &nullval,
 		      table+k*nrows,&dummy,&stat);
 	*/
 #ifdef __WXDEBUG__
@@ -1618,24 +1619,24 @@ FitsFile::~FitsFile()
   hdu.clear();
 }
 
-bool FitsFile::Status() const 
-{ 
-  return status; 
-}
-
-size_t FitsFile::HduCount() const 
-{ 
-  return hdu.size(); 
-}
-
-int FitsFile::size() const 
-{ 
-  return hdu.size(); 
-}
-
-FitsHdu FitsFile::Hdu(size_t n) const 
+bool FitsFile::Status() const
 {
-  wxASSERT(0 <= n && n < hdu.size()); 
+  return status;
+}
+
+size_t FitsFile::HduCount() const
+{
+  return hdu.size();
+}
+
+int FitsFile::size() const
+{
+  return hdu.size();
+}
+
+FitsHdu FitsFile::Hdu(size_t n) const
+{
+  wxASSERT(0 <= n && n < hdu.size());
   return hdu[n];
 }
 
@@ -1804,13 +1805,13 @@ bool FitsFile::Save(const wxString& name)
       fits_create_img(f, FLOAT_IMG, naxis, naxes, &status);
       merge_head(f,Hdu(k),&status);
       fits_write_img(f, TFLOAT, fpixel, nelements, (float *) image.PixelData(), &status);
-      
+
 
     }
     else if( type == HDU_TABLE ) {
 
       const FitsTable table(Hdu(k));
-      
+
       int tfields = table.Ncols();
       char **ttype = new char*[tfields];
       char **tform = new char*[tfields];
@@ -1938,7 +1939,7 @@ int FitsFile::merge_head(fitsfile *f, const FitsHdu& hdu, int *status) const
       }
     }
 
-    if( ! presented ) 
+    if( ! presented )
       fits_write_record(f,record.fn_str(),status);
   }
 
@@ -1993,7 +1994,6 @@ wxArrayString FitsColumns(const wxString& name)
   }
   fits_close_file(f,&stat);
   fits_report_error(stderr,stat);
-  
+
   return cols;
 }
-
