@@ -2,7 +2,7 @@
 
   XMunipack - FITS headers
 
-  Copyright © 2009-2013 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2013, 2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -10,12 +10,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -55,14 +55,14 @@ enum hdu_type {
 };
 
 enum hdu_flavour {
-  HDU_IMAGE_LINE, HDU_IMAGE_FRAME, HDU_IMAGE_CUBE, HDU_IMAGE_COLOR, 
+  HDU_IMAGE_LINE, HDU_IMAGE_FRAME, HDU_IMAGE_CUBE, HDU_IMAGE_COLOR,
   HDU_IMAGE_UNKNOWN,
   HDU_TABLE_BIN, HDU_TABLE_ASCII, HDU_TABLE_UNKNOWN,
   HDU_DUMMY
 };
 
 enum itt_type {
-  ITT_FIRST, 
+  ITT_FIRST,
   ITT_LINE, ITT_ASINH, ITT_LOG, ITT_SQRT, ITT_GAMMA,
   ITT_NORM, ITT_LOGIS, ITT_ATAN, ITT_SQR,
   ITT_LAST
@@ -76,14 +76,14 @@ enum itt_kind {
 
 enum color_palette {
   PAL_FIRST,
-  PAL_GREY, PAL_SEPIA, PAL_VGA, PAL_AIPS0, PAL_STAIR, PAL_COLOR, PAL_SAW, 
-  PAL_RAIN, PAL_MAD, PAL_COOL, PAL_HEAT, PAL_SPRING, PAL_WRAP, 
+  PAL_GREY, PAL_SEPIA, PAL_VGA, PAL_AIPS0, PAL_STAIR, PAL_COLOR, PAL_SAW,
+  PAL_RAIN, PAL_MAD, PAL_COOL, PAL_HEAT, PAL_SPRING, PAL_WRAP,
   PAL_LAST
 };
 
 enum color_space {
   COLORSPACE_FIRST,
-  COLORSPACE_XYZ, 
+  COLORSPACE_XYZ,
   COLORSPACE_LAST
 };
 
@@ -92,14 +92,14 @@ enum color_temperature {
 };
 
 enum units_type {
-  UNIT_FIRST, 
-  UNIT_COUNT, UNIT_MAG, UNIT_PHOTON, UNIT_FLUX, UNIT_FNU, UNIT_FLAM, UNIT_ABMAG, 
+  UNIT_FIRST,
+  UNIT_COUNT, UNIT_MAG, UNIT_PHOTON, UNIT_FLUX, UNIT_FNU, UNIT_FLAM, UNIT_ABMAG,
   UNIT_STMAG,
   UNIT_LAST
 };
 
 enum coords_type {
-  COO_FIRST, 
+  COO_FIRST,
   COO_PIXEL, COO_EQDEG, COO_EQSIX,
   COO_LAST
 };
@@ -160,7 +160,8 @@ public:
   virtual inline float Pixel(int, int) const { return 0; }
   virtual inline wxString Pixel_str(int, int) const;
 
-  virtual bool GetWCS(double&,double&,double&,double&,double&,double&) const;
+  virtual bool GetWCS(double&,double&,double&,double&,double&,double&,
+		      double&) const;
 
 protected:
 
@@ -205,7 +206,7 @@ public:
   FitsArray(const FitsHdu&);
   virtual ~FitsArray();
   FitsArray Copy() const;
-  
+
   int Naxis() const;
   long Naxes(const int n) const;
   inline float Pixel(int) const;
@@ -218,7 +219,7 @@ public:
   wxString Flavour_str() const;
 
   bool IsOk() const;
-  
+
 protected:
 
   wxObjectRefData* CreateRefData() const;
@@ -230,7 +231,7 @@ private:
 
 };
 
-inline float FitsArray::Pixel(int i) const 
+inline float FitsArray::Pixel(int i) const
 {
   FitsArrayData *data = static_cast<FitsArrayData *>(m_refData);
   wxASSERT(data);
@@ -265,7 +266,7 @@ public:
 private:
 
   float med, mad, min, max;
-  float QMed(int, float *, int);  
+  float QMed(int, float *, int);
 
 };
 
@@ -373,10 +374,16 @@ inline wxString FitsTableColumn::Cell_str(int x) const
     a.Printf("%g",data->ftable[x]);
   else if( data->dtable )
     a.Printf("%lg",data->dtable[x]);
-  else if( data->itable )
+  else if( data->stable )
+    a.Printf("%d",data->stable[x]);
+  else if( data->ltable )
     a.Printf("%ld",data->ltable[x]);
   else if( data->itable )
     a.Printf("%d",data->itable[x]);
+  else if( data->btable )
+    a.Printf("%d",data->btable[x]);
+  else if( data->otable )
+    a = data->otable[x] ? "T" : "F";
   else if( data->ctable )
     a = data->ctable[x];
 
@@ -528,7 +535,7 @@ inline wxString FitsTable::Cell_str(int x, int y) const
 
   /*
   switch(data->typecode[y]) {
-  case TBYTE: 
+  case TBYTE:
   case TINT:
   case TLONG:
     a.Printf("%d",(int **) data->table[x*data->nrows + y]); break;
@@ -599,7 +606,7 @@ private:
 
   void Recognize();
   int merge_head(fitsfile *, const FitsHdu&, int *) const;
-  
+
 };
 
 
@@ -609,7 +616,7 @@ class FitsMetaHdu: public FitsHeader
 {
 public:
   FitsMetaHdu(const FitsHdu&, const wxImage&);
-  FitsMetaHdu(const wxArrayString&, const wxImage&, int, long, 
+  FitsMetaHdu(const wxArrayString&, const wxImage&, int, long,
 	      const std::vector<long>&, const wxString&, const wxString&);
 
   size_t Naxis() const;
@@ -692,16 +699,16 @@ private:
 
 class FitsHisto: public wxObject
 {
-public: 
+public:
   FitsHisto();
   FitsHisto(int,int*,float*);
   FitsHisto(const FitsArray& , int=0);
   FitsHisto(const FitsArray& , float, float, int=0);
   virtual ~FitsHisto();
 
-  
+
   int NBins() const;
-  int Hist(int n) const; 
+  int Hist(int n) const;
   float Cents(int n) const;
   float BinWidth() const;
   float CentsMin() const;
@@ -722,11 +729,11 @@ class FitsGeometry: public FitsArray
 {
 public:
   FitsGeometry(const FitsArray&);
-  
+
   FitsArray Scale(float);
   FitsArray Scale(const long *);
   FitsArray Scale(int,int);
-  
+
   FitsArray SubArray(int,int,int,int);
   void SetSubArray(int,int,const FitsArray&);
 
@@ -839,9 +846,9 @@ public:
   void NightVision(int,float*,float*,float*,float*);
   void Instr_XYZ(int,size_t,const float **,float*,float*,float*);
   void TuneColors(int,float*,float*,float*);
-  
+
   float Scotopic(float,float,float);
-  //  void Convert(float, float, float, 
+  //  void Convert(float, float, float,
   //	       unsigned char &, unsigned char &, unsigned char &);
   //  void Transform(size_t, float *, float&, float&, float&);
 
@@ -899,7 +906,7 @@ inline void FitsColor::Luv_XYZ(float L, float u, float v, float Yn,
   float u1 = u/s + uwhite;
   float v1 = v/s + vwhite;
 
-  if( L <= 8.0 ) 
+  if( L <= 8.0 )
     Y = L*0.0011071*Yn; /* = powf(3.0/29.0,3) */
   else {
     float t = (L + 16.0)/116.0;
@@ -919,7 +926,7 @@ class FitsPalette: public wxObject
 public:
   FitsPalette(int =PAL_GREY);
   virtual ~FitsPalette();
-  
+
   void SetPalette(int);
   void SetPalette(const wxString&);
   void SetNegative(bool=false);
@@ -927,7 +934,7 @@ public:
   int GetPalette() const;
   wxString GetPalette_str() const;
   bool GetNegative() const;
-  
+
   unsigned char R(int i) const;
   unsigned char G(int i) const;
   unsigned char B(int i) const;
@@ -936,12 +943,12 @@ public:
   const unsigned char *RData() const;
   const unsigned char *GData() const;
   const unsigned char *BData() const;
-  
+
   static wxString Type_str(int);
   static wxArrayString Type_str();
-  
+
 private:
-  
+
   int pal;
   bool negative;
 
@@ -956,18 +963,20 @@ class FitsProjection
 {
 public:
   FitsProjection();
-  FitsProjection(const wxString& t, double a,double d,double x,double y,double s,double r);
-  FitsProjection(const wxString& t, double a,double d, double x, double y, double cd11, double cd12, double cd21, double cd22);
-  
+  FitsProjection(const wxString& t, double a,double d,double x,double y,
+		 double s,double r, double z);
+  FitsProjection(const wxString& t, double a,double d, double x, double y,
+		 double cd11, double cd12, double cd21, double cd22);
+
   void ad2xy(double,double,double&,double&);
   void xy2ad(double,double,double&,double&);
   void gnomon(double,double,double&,double&);
   void ignomon(double,double,double&,double&);
 
 private:
-  
+
   wxString type;
-  double acen, dcen, xcen, ycen, scale, angle;
+  double acen, dcen, xcen, ycen, scale, angle, reflex;
 
 };
 
@@ -983,7 +992,7 @@ public:
   void SetType(int);
   void SetType(const wxString&);
   coords_type GetType() const;
-  
+
   void GetEq(int,int,double&,double&);
   void RaSix(double,int&,int&,double&);
   void DecSix(double,char&,int&,int&,double&);
@@ -1014,7 +1023,7 @@ class PhotoFilter
 {
 public:
   PhotoFilter(): flux0(-1.0), leff(0.0), lwidth(0.0) {}
-  PhotoFilter(const wxString& n,double f0, double le, double lw): 
+  PhotoFilter(const wxString& n,double f0, double le, double lw):
     name(n),flux0(f0),leff(le),lwidth(lw) {}
 
   bool IsOk() const { return flux0 > 0.0; }
@@ -1057,9 +1066,9 @@ class PhotoConv
 
 
  public:
-  PhotoConv() {} 
+  PhotoConv() {}
   PhotoConv(const PhotoFilter&, double, double, double, double);
-  
+
   double GetFlux(double) const;
   double GetFnu(double) const;
   double GetFlam(double) const;
@@ -1067,7 +1076,7 @@ class PhotoConv
   double GetMag(double) const;
   double GetABMag(double) const;
   double GetSTMag(double) const;
-  
+
 };
 
 
@@ -1075,7 +1084,7 @@ class FitsValue
 {
 public:
   FitsValue();
-  FitsValue(const FitsArray&, const wxString&, const wxString&, const wxString&, 
+  FitsValue(const FitsArray&, const wxString&, const wxString&, const wxString&,
 	    const wxString&, const wxString&);
   FitsValue(const FitsArray&,const FitsArray&,const FitsArray&);
 
@@ -1088,12 +1097,12 @@ public:
   wxString Get_str(int,int) const;
 
   static wxString Label_str(int);
-  static wxArrayString Label_str();  
+  static wxArrayString Label_str();
 
   bool HasCal() const { return hascal; }
 
 private:
-  
+
   units_type type;
   bool hascal;
   std::vector<FitsArray> arrays;
@@ -1113,14 +1122,14 @@ private:
 class FitsTime
 {
 public:
-  FitsTime():year(0), month(0), day(0), hour(0), minute(0), second(0), 
+  FitsTime():year(0), month(0), day(0), hour(0), minute(0), second(0),
 	     milisecond(0) {}
   FitsTime(const wxString& );
-  
+
   void SetDateTime(const wxString& );
   void SetDate(const wxString& );
   void SetTime(const wxString& );
-  
+
   double Jd() const;
   wxString Date() const { return date; }
   wxString Time() const { return time; }
