@@ -1,9 +1,9 @@
 /*
 
-  xmunipack - FITS view 
+  xmunipack - FITS view
 
 
-  Copyright © 2009 - 2014 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009 - 2014, 2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -11,12 +11,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -127,14 +127,14 @@ protected:
 
     return wxTreeCtrl::Create(parent,wxID_ANY,wxDefaultPosition,wxDefaultSize,
 			      (wxTR_DEFAULT_STYLE | wxTR_HAS_BUTTONS | wxTR_HIDE_ROOT | wxTR_FULL_ROW_HIGHLIGHT) & ~wxTR_NO_LINES);
-    
+
   }
-  
+
 
   // Return pointer to the created control
   virtual wxWindow *GetControl() { return this; }
 
-    
+
     virtual wxSize GetAdjustedSize( int minWidth,
                                     int WXUNUSED(prefHeight),
                                     int maxHeight )
@@ -194,8 +194,8 @@ protected:
     {
         int resFlags;
         wxTreeItemId itemHere = HitTest(event.GetPosition(),resFlags);
-        if ( itemHere.IsOk() && 
-	     ((resFlags & wxTREE_HITTEST_ONITEMLABEL) || 
+        if ( itemHere.IsOk() &&
+	     ((resFlags & wxTREE_HITTEST_ONITEMLABEL) ||
 	      (resFlags & wxTREE_HITTEST_ONITEMICON) ||
 	      (resFlags & wxTREE_HITTEST_ONITEMSTATEICON) ||
 	      (resFlags & wxTREE_HITTEST_ONITEMBUTTON) ||
@@ -213,7 +213,7 @@ protected:
     {
         int resFlags;
         wxTreeItemId itemHere = HitTest(event.GetPosition(),resFlags);
-        if ( itemHere.IsOk() && 
+        if ( itemHere.IsOk() &&
 	     ((resFlags & wxTREE_HITTEST_ONITEMLABEL) ||
 	      (resFlags & wxTREE_HITTEST_ONITEMICON) ||
 	      (resFlags & wxTREE_HITTEST_ONITEMSTATEICON) ||
@@ -229,7 +229,7 @@ protected:
 	    if( item.IsOk() ) {
 	      xTreeItemData *data = dynamic_cast<xTreeItemData *>(GetItemData(item));
 	      wxASSERT(data);
-	      
+
 	      MuniHduEvent ev(EVT_HDU);
 	      ev.hdu = data->index;
 	      wxQueueEvent(GetGrandParent(),ev.Clone());
@@ -263,7 +263,7 @@ protected:
 public:
 
   void SetMeta(const FitsMeta& meta) {
-    
+
     DeleteAllItems();
 
     wxFont fn(*wxNORMAL_FONT);
@@ -275,7 +275,7 @@ public:
     }
     icons->Add(wxBitmap(MuniIcon::ListIcon(meta.GetIcon(),ssize)));
     AssignImageList(icons);
-    
+
     wxTreeItemId root = AddRoot("<root>");
 
     wxTreeItemId hub = AppendItem(root,meta.GetName(),meta.HduCount(),-1,new xTreeItemData(-1));
@@ -294,11 +294,11 @@ public:
     wxTreeItemIdValue cookie;
     wxTreeItemId hub = GetFirstChild(root,cookie);
     while ( hub.IsOk() ) {
-      
+
       xTreeItemData *data = dynamic_cast<xTreeItemData *>(GetItemData(hub));
       wxASSERT(data);
       if( data->index == hdu ) {
-	SelectItem(hub);	
+	SelectItem(hub);
 	return;
       }
       else {
@@ -313,7 +313,7 @@ public:
 	    SelectItem(child);
 	    return;
 	  }
-	  
+
 	  child = GetNextChild(hub,cookies);
         }
       }
@@ -338,7 +338,7 @@ MuniView::MuniView(wxWindow *w, MuniConfig *c):
   // menus
   menuFile = new wxMenu;
   menuFile->Append(wxID_NEW);
-  
+
   //  menuFile->Append(ID_NEW_VIEW, _("&New View..."));
   //  menuFile->Append(ID_NEW_BROWSER,_("&New Browser..."));
   menuFile->Append(wxID_OPEN);
@@ -501,7 +501,7 @@ void MuniView::OnClose(wxCloseEvent& event)
       return;
     }
   }
-  
+
 
   // if( event.CanVeto() && /*fits.IsModified()*/ IsModified() ) {
   //   wxMessageDialog dialog(this,"Do you really want to leave this window ?",
@@ -519,9 +519,9 @@ void MuniView::OnClose(wxCloseEvent& event)
 
   //  if( display->IsRendering() )
   MuniDisplay *display = dynamic_cast<MuniDisplay *>(place);
-  if( display ) 
+  if( display )
     display->StopRendering();
-  
+
 
   // if( ! backup.IsEmpty() ) {
   //   wxBusyCursor wait;
@@ -568,7 +568,7 @@ void MuniView::OnUpdateFit(wxUpdateUIEvent& event)
   if( !twin || twin->IsFullScreen()) return;
 
   MuniDisplay *display = dynamic_cast<MuniDisplay *>(place);
-  if( display ) 
+  if( display )
     event.Check(display->GetFit());
 }
 
@@ -578,7 +578,7 @@ void MuniView::OnUpdateNFit(wxUpdateUIEvent& event)
   if( !twin || twin->IsFullScreen()) return;
 
   MuniDisplay *display = dynamic_cast<MuniDisplay *>(place);
-  if( display ) 
+  if( display )
     event.Enable(!display->GetFit());
 }
 
@@ -617,12 +617,12 @@ void MuniView::LoadFile(const wxString& filename)
 {
   //  wxASSERT(backup.IsEmpty());
   //  RemoveBackup();
-  
+
   if( IsModified() ) {
     if( Unsaved(fits.GetName()) == wxID_CANCEL )
       return;
   }
-  
+
   //  backup.Clear();
   meta = FitsMeta();
   LoadStart(filename);
@@ -723,7 +723,7 @@ void MuniView::OnLoadFinish(FitsOpenEvent& event)
 		     config->icon_size);
       meta = FitsMeta(fits,micon.GetIcon(),micon.GetList());
       SetMeta(meta);
-    } 
+    }
 
     wxASSERT(meta.IsOk());
     wxASSERT(fits.HduCount() > 0);
@@ -813,7 +813,7 @@ void MuniView::SetMeta(const FitsMeta& m)
     viewid.push_back(id);
   }
 
-  
+
   menuWin->AppendSeparator();
 
   menuWin->Append(wxID_BACKWARD,"Previous\tAlt+Left");
@@ -849,7 +849,7 @@ int MuniView::EstimHduSel(const FitsMeta& meta)
 //   double xmin,xmax;
 //   bool color = fits.Type() == FITS_COLOR;
 
-  
+
 //   if( color ) {
 
 //     /*
@@ -878,7 +878,7 @@ int MuniView::EstimHduSel(const FitsMeta& meta)
 //     // convrt to XYZ, Luv
 //     //    hits = FitsHisto(
 //     hist = FitsHisto(fits.Hdu(2),xmin,xmax);
-//   } 
+//   }
 //   else if( fits.Type() == FITS_GRAY ) {
 //     FitsArrayStat array(fits.Hdu(0));
 //     xmin = array.Med() - 5.0*array.Mad();
@@ -919,7 +919,7 @@ void MuniView::FileClose(wxCommandEvent& WXUNUSED(event))
 void MuniView::FileOpen(wxCommandEvent& WXUNUSED(event))
 {
   if( IsModified() ) {
-    if( Unsaved(fits.GetName()) == wxID_CANCEL ) 
+    if( Unsaved(fits.GetName()) == wxID_CANCEL )
       return;
   }
 
@@ -1027,7 +1027,7 @@ void MuniView::FileExport(wxCommandEvent& WXUNUSED(event))
 	for(int i = 0; i < table.Width(); i++)
 	  cout << " " << table.Pixel_str(i,j) ;
 	cout << endl;
-	//	if( j % 100 == 0) dialog.Pulse();      
+	//	if( j % 100 == 0) dialog.Pulse();
       }
     }
   }
@@ -1052,7 +1052,7 @@ void MuniView::FileExport(wxCommandEvent& WXUNUSED(event))
 
       wxFileOutputStream output(select.GetPath());
       wxTextOutputStream cout(output);
-      
+
       const FitsHdu head = fits.Hdu(hdusel);
       for(size_t i = 0; i < head.GetCount(); i++)
 	cout << head.Item(i) << endl;
@@ -1061,7 +1061,7 @@ void MuniView::FileExport(wxCommandEvent& WXUNUSED(event))
 
   else
     wxFAIL_MSG("----- WARNING: Unreachable code.");
-    
+
 }
 
 /*
@@ -1129,12 +1129,12 @@ void MuniView::OnMenuZoom(wxCommandEvent& event)
 
   double zoom = 1.0;
 
-  wxString entry;  
+  wxString entry;
   switch(event.GetId()) {
   case wxID_ZOOM_FIT: zoom = -1.0; break;
   case wxID_ZOOM_100: zoom = 1.0; break;
   }
- 
+
   MuniTuneEvent ev(EVT_TUNE,ID_ZOOM_SCALE);
   ev.x = zoom;
   if( event.GetId() == wxID_ZOOM_FIT )
@@ -1146,11 +1146,11 @@ void MuniView::OnMenuZoom(wxCommandEvent& event)
 }
 
 void MuniView::OnMenuItt(wxCommandEvent& event)
-{ 
+{
   wxMenu *menuTune = GetMenuBar()->GetMenu(GetMenuBar()->FindMenu(MENU_TUNE));
   wxMenuItem *item = menuTune->FindItem(menuTune->FindItem(TONE_CURVES));
   wxMenu *menuProfile= item->GetSubMenu();
-  wxASSERT(place && menuTune && menuProfile && 
+  wxASSERT(place && menuTune && menuProfile &&
 	   menuProfile->FindItem(event.GetId()));
 
   MuniTuneEvent ev(EVT_TUNE,ID_ITT_TYPE);
@@ -1160,7 +1160,7 @@ void MuniView::OnMenuItt(wxCommandEvent& event)
 }
 
 void MuniView::OnCycleItt(wxCommandEvent& event)
-{ 
+{
   wxMenu *menuTune = GetMenuBar()->GetMenu(GetMenuBar()->FindMenu(MENU_TUNE));
   wxMenuItem *item = menuTune->FindItem(menuTune->FindItem(TONE_CURVES));
   wxMenu *menuProfile= item->GetSubMenu();
@@ -1189,11 +1189,11 @@ void MuniView::OnCycleItt(wxCommandEvent& event)
 }
 
 void MuniView::OnMenuPal(wxCommandEvent& event)
-{ 
+{
   wxMenu *menuTune = GetMenuBar()->GetMenu(GetMenuBar()->FindMenu(MENU_TUNE));
   wxMenuItem *item = menuTune->FindItem(menuTune->FindItem(COLOR_PALETTES));
   wxMenu *menuPalette= item->GetSubMenu();
-  wxASSERT(place && menuTune && menuPalette && 
+  wxASSERT(place && menuTune && menuPalette &&
 	   menuPalette->FindItem(event.GetId()));
 
   MuniTuneEvent ev(EVT_TUNE,ID_PALETTE_TYPE);
@@ -1203,7 +1203,7 @@ void MuniView::OnMenuPal(wxCommandEvent& event)
 }
 
 void MuniView::OnCyclePal(wxCommandEvent& event)
-{ 
+{
   wxMenu *menuTune = GetMenuBar()->GetMenu(GetMenuBar()->FindMenu(MENU_TUNE));
   wxMenuItem *item = menuTune->FindItem(menuTune->FindItem(COLOR_PALETTES));
   wxMenu *menuPalette= item->GetSubMenu();
@@ -1224,7 +1224,7 @@ void MuniView::OnCyclePal(wxCommandEvent& event)
   }
   wxASSERT(!label.IsEmpty() );
 
-  menuPalette->Check(itemid,true);  
+  menuPalette->Check(itemid,true);
 
   MuniTuneEvent ev(EVT_TUNE,ID_PALETTE_TYPE);
   ev.SetString(label);
@@ -1232,7 +1232,7 @@ void MuniView::OnCyclePal(wxCommandEvent& event)
 }
 
 void MuniView::OnMenuNegative(wxCommandEvent& event)
-{ 
+{
   wxASSERT(place);
 
   MuniTuneEvent ev(EVT_TUNE,ID_PALETTE_NEGATIVE);
@@ -1247,7 +1247,7 @@ void MuniView::OnTuneFine(MuniTuneEvent& event)
   wxMenu *menuTune = GetMenuBar()->GetMenu(GetMenuBar()->FindMenu(MENU_TUNE));
   wxMenuItem *item = menuTune->FindItem(menuTune->FindItem(COLOR_PALETTES));
   wxMenu *menuPalette = 0;
-  if( item ) 
+  if( item )
     menuPalette = item->GetSubMenu();
 
   item = menuTune->FindItem(menuTune->FindItem(TONE_CURVES));
@@ -1258,12 +1258,12 @@ void MuniView::OnTuneFine(MuniTuneEvent& event)
   int itemid;
 
   switch(event.GetId()) {
-  case ID_ITT_TYPE: 
+  case ID_ITT_TYPE:
     itemid = menuProfile->FindItem(event.GetString());
     wxASSERT(itemid != wxNOT_FOUND);
     menuProfile->Check(itemid,true);
     break;
-  case ID_PALETTE_TYPE: 
+  case ID_PALETTE_TYPE:
     if( menuPalette ) {
       itemid = menuPalette->FindItem(event.GetString());
       wxASSERT(itemid != wxNOT_FOUND);
@@ -1510,7 +1510,7 @@ void MuniView::HduSelect(int h)
   if( hdusel >= 0 ) {
 
     const FitsMetaHdu hdu = meta.Hdu(hdusel);
-    
+
     switch(fits.Hdu(hdusel).Type()) {
     case HDU_IMAGE:  CreateDisplay(); break;
     case HDU_TABLE:  CreateGrid();    break;
@@ -1580,7 +1580,7 @@ void MuniView::DeleteResume()
 void MuniView::CreateHead()
 {
   ReplacePlace(new MuniHead(this,config));
-  static_cast<MuniHead *>(place)->SetHdu(fits.Hdu(hdusel)); 
+  static_cast<MuniHead *>(place)->SetHdu(fits.Hdu(hdusel));
   GetToolBar()->EnableTool(wxID_HOME,true);
   GetToolBar()->EnableTool(ID_INFO,true);
 
@@ -1636,7 +1636,7 @@ void MuniView::CreateDisplay()
 {
   ReplacePlace(new MuniDisplay(this,config));
   static_cast<MuniDisplay *>(place)->SetHdu(fits.Hdu(hdusel),
-					    meta.Hdu(hdusel).GetIcon()); 
+					    meta.Hdu(hdusel).GetIcon());
 
   // menus
   menuView->AppendCheckItem(ID_DETAIL,"Detail Panel");
@@ -1717,7 +1717,7 @@ void MuniView::CreateDisplay()
 
   // toolbar
   MuniArtIcons ico(wxART_TOOLBAR,wxSize(22,22));
-  
+
   wxToolBar *tbar = GetToolBar();
   wxASSERT(tbar);
 
@@ -1741,10 +1741,10 @@ void MuniView::CreateDisplay()
     if( fits.Hdu(i).GetKey("EXTNAME").Find("MUNIPACK") != wxNOT_FOUND ) {
       FitsTable t(fits.Hdu(i));
       dynamic_cast<MuniDisplay *>(place)->SetStars(t);
-      /*      
+      /*
       wxMemoryOutputStream ostream;
       t.GetStarChart(ostream);
-      
+
       wxMemoryInputStream istream(ostream);
       dynamic_cast<MuniDisplay *>(place)->SetOverlay(istream);
       */
@@ -1769,8 +1769,8 @@ void MuniView::CreateDisplay()
   Bind(EVT_TUNE,&MuniView::OnTuneFine,this);
   //  Bind(EVT_DIALOG,&MuniView::OnPhotometry,this,ID_PHOT);
 
-  double xpix, ypix, alpha, delta, scale, angle;
-  if( fits.Hdu(hdusel).GetWCS(xpix, ypix, alpha, delta, scale, angle) ) {
+  double xpix, ypix, alpha, delta, scale, angle, reflex;
+  if( fits.Hdu(hdusel).GetWCS(xpix, ypix, alpha, delta, scale, angle, reflex) ){
     menuView->Check(ID_GRID,config->display_grid);
     wxASSERT(dynamic_cast<MuniDisplay *>(place));
     dynamic_cast<MuniDisplay *>(place)->ShowGrid(config->display_grid);
@@ -1869,7 +1869,7 @@ void MuniView::OnSize(wxSizeEvent& event)
   //  wxASSERT(place);
   //Layout();
 
-  // arrange stretch space in toolbar 
+  // arrange stretch space in toolbar
   //  wxSize size(GetSize());
 
   /*
@@ -1879,7 +1879,7 @@ void MuniView::OnSize(wxSizeEvent& event)
   // Black Magick. The part of code together with code in display.cpp
   // setups scrolling for images. I had spend lot of time with looking
   // for a way how correctly does it. The principle is set size
-  // of place to minumum while deriving virtual size by image. 
+  // of place to minumum while deriving virtual size by image.
 
   //  wxPostEvent(place,event);
 
@@ -1947,7 +1947,7 @@ void MuniView::OnColoringFinish(wxCommandEvent& event)
 
 // void MuniView::RunShell(const queue<MuniCommander>& com)
 // {
-//   //  wxBeginBusyCursor(); // must be called out of exec and write to 
+//   //  wxBeginBusyCursor(); // must be called out of exec and write to
 
 //   shell = new MuniShell(GetEventHandler(),com);
 
@@ -1958,7 +1958,7 @@ void MuniView::OnColoringFinish(wxCommandEvent& event)
 //   archiveprop->SetLabel(_("Files are being processed."));
 //   SetArchiveSize();
 //   */
-// } 
+// }
 
 // void MuniView::OnShell(MuniShellEvent& event)
 // {
@@ -1981,7 +1981,7 @@ void MuniView::OnColoringFinish(wxCommandEvent& event)
 //   console->AppendError(event.err);
 //   */
 
-//   wxArrayString results = event.res; 
+//   wxArrayString results = event.res;
 //   for(size_t i = 0; i < results.GetCount(); i++) {
 //     wxLogDebug(results[i]);
 //     LoadFile(results[i]);
