@@ -3,7 +3,7 @@
   XMunipack
 
 
-  Copyright © 2009-2015 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2015, 2017 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -11,12 +11,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -172,7 +172,7 @@ class MuniFileProperties: public wxDialog
 {
 public:
   MuniFileProperties(wxWindow *w, const FitsMeta& , const MuniConfig *);
-  
+
 private:
 
   FitsMeta meta;
@@ -205,7 +205,7 @@ private:
 
 class MuniConsole: public wxFrame
 {
-public: 
+public:
   MuniConsole(wxWindow *, MuniConfig *);
   virtual ~MuniConsole();
   void AppendOutput(const wxArrayString&);
@@ -246,18 +246,18 @@ private:
 
 class MuniLog: public wxLogWindow
 {
-public: 
+public:
   MuniLog(wxWindow *);
   virtual ~MuniLog();
-  
+
   virtual bool OnFrameClose(wxFrame *);
   bool Visibility();
-  
+
 private:
 
   wxWindow *topwin;
   bool visible;
-  
+
 };
 
 class MuniAbout
@@ -272,9 +272,9 @@ class MuniHelp: public wxFrame
 public:
   MuniHelp(MuniConfig *);
   virtual ~MuniHelp();
-  
+
 private:
-  
+
   wxHtmlWindow *web;
   wxString home;
   wxTextCtrl *turl;
@@ -303,7 +303,7 @@ private:
   DECLARE_EVENT_TABLE()
 };
 
- 
+
 // class MuniGraph: public wxPanel
 // {
 // public:
@@ -335,7 +335,7 @@ private:
 // {
 // public:
 //   MuniStrip(wxWindow *, const wxSize&, const FitsItt&, const FitsPalette&);
-  
+
 //   void SetItt(const FitsItt&);
 //   void SetPalette(const FitsPalette&);
 
@@ -381,7 +381,7 @@ public:
   //  virtual ~MuniThumbCanvas() {}
   void SetIcon(const wxBitmap&);
   void SetIcon(const wxImage&);
-  
+
 private:
 
   wxBitmap icon;
@@ -403,7 +403,7 @@ public:
 protected:
 
   MuniConfig *config;
-  MuniPipe pipe;  
+  MuniPipe pipe;
   wxTimer timer;
   bool running, readonly;
   int exitcode;
@@ -425,7 +425,7 @@ public:
   void DrawObjects(const std::vector<double>&,const std::vector<double>&,const std::vector<double>&);
 
 private:
-  
+
   const wxColour gold,DarkOrange2;
   std::vector<wxObject *> objects;
 
@@ -573,7 +573,7 @@ private:
   void OnMatchType(wxCommandEvent&);
   void OnFullMatch(wxCommandEvent&);
   void OnChoiceUnits(wxCommandEvent&);
-  
+
 };
 
 class MuniAstrometry: public wxDialog
@@ -593,7 +593,7 @@ private:
   wxGauge *progress;
   wxStaticText *overlayid, *refcatid, *info, *infolabel, *proginfo, *proglabel;
   wxBoxSizer *autosizer;
-  wxCheckBox *overlay_check;
+  wxCheckBox *overlay_check, *reflex_checkbox;
   FitsArray array;
   FitsTable catalogue, stars, coverlay;
   wxTimer timer;
@@ -603,7 +603,7 @@ private:
 
   int nstars,nhist;
   double maglim, s0, rms;
-  double xoff,yoff,alpha, delta, scale, angle, amin, dmin, fmin;
+  double xoff,yoff,alpha, delta, scale, reflex, angle, amin, dmin, fmin;
   wxString proj,label_ra,label_dec,label_mag, label_pmra, label_pmdec;
   bool init_par, init_file, init_ref, running, parsing, unsaved,
     draw_overlay, edited, relative, tmpcat,readonly,showtooltip;
@@ -620,6 +620,7 @@ private:
   void OnCalibrateStop(wxCommandEvent&);
   void OnCalibrateFinish(wxProcessEvent&);
   void OnOverlay(wxCommandEvent&);
+  void OnReflex(wxCommandEvent&);
   void OnDrawOverlay(wxCommandEvent&);
   void OnReference(wxCommandEvent&);
   void OnTimer(wxTimerEvent&);
@@ -652,7 +653,7 @@ private:
 class MuniAstrolog
 {
   wxDateTime datetime;
-  
+
  public:
   MuniAstrolog();
   MuniAstrolog(const wxDateTime&);
@@ -694,7 +695,7 @@ private:
   void ParseOutput();
   void OnProcess(wxCommandEvent&);
   void OnTimer(wxTimerEvent&);
-  void OnFinish(wxProcessEvent&); 
+  void OnFinish(wxProcessEvent&);
   void OnReference(wxCommandEvent&);
   void OnChoiceProj(wxCommandEvent&);
   void EraseTemp();
@@ -1057,7 +1058,7 @@ private:
   wxString GetFullPath(const wxString& =wxEmptyString) const;
   wxString DissolveRoot(const wxString&) const;
   long NextAvailableIndex() const;
-  wxArrayString GetItems(const wxString&, int, 
+  wxArrayString GetItems(const wxString&, int,
 			 const wxString& =wxEmptyString) const;
   bool IsAbsPath(const wxString&) const;
   void OnMetaOpen(MetaOpenEvent&);
@@ -1107,7 +1108,7 @@ public:
   virtual ~MetaRender();
 
 protected:
-  
+
   wxEvtHandler *handler;
   MuniConfig *config;
 
@@ -1246,7 +1247,7 @@ class MuniListWindow: public wxWindow
 {
 public:
   MuniListWindow(wxWindow *, wxWindowID, long = 0, MuniConfig * = 0);
-  
+
   void AddWindow(wxWindow *);
   void SetStyle(long);
 
@@ -1409,8 +1410,8 @@ private:
 class MuniBrowserSearch: public wxSearchCtrl
 {
 public:
-  MuniBrowserSearch(wxWindow *, wxWindowID, const wxString& =wxEmptyString, 
-		    const wxPoint& =wxDefaultPosition, 
+  MuniBrowserSearch(wxWindow *, wxWindowID, const wxString& =wxEmptyString,
+		    const wxPoint& =wxDefaultPosition,
 		    const wxSize& =wxDefaultSize, long =0);
 
   std::vector<long> Find(const std::vector<FitsMeta>&) const;
@@ -1553,7 +1554,7 @@ private:
   void OnUpdateTbot(wxUpdateUIEvent&);
   void OnUpdateCut(wxUpdateUIEvent&);
   void OnUpdatePaste(wxUpdateUIEvent&);
-  
+
 };
 
 
@@ -1562,8 +1563,7 @@ class XMunipack: public wxApp
   bool OnInit();
   int OnExit();
   void OnFatalException();
-  
+
   MuniConfig *config;
 
 };
-
